@@ -6,7 +6,7 @@
 #'
 #' @inheritParams step_center
 #' @param lambdas A numeric vector of transformation values. This
-#'  is `NULL` until computed by [prep.recipe()].
+#'  is `NULL` until computed by [prep()].
 #' @param limits A length 2 numeric vector defining the range to
 #'  compute the transformation parameter lambda.
 #' @param num_unique An integer to specify minimum required unique
@@ -32,9 +32,11 @@
 #'  closed to the bounds, or if the optimization fails, a value of
 #'  `NA` is used and no transformation is applied.
 #'
-#' When you [`tidy()`] this step, a tibble with columns `terms` (the
-#'  selectors or variables selected) and `value` (the
-#'  lambda estimate) is returned.
+#' # Tidying
+#'
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
+#' `terms` (the selectors or variables selected) and `value` (the
+#' lambda estimate) is returned.
 #'
 #' @references Sakia, R. M. (1992). The Box-Cox transformation technique:
 #'   A review. *The Statistician*, 169-178..
@@ -66,7 +68,7 @@ step_BoxCox <-
     add_step(
       recipe,
       step_BoxCox_new(
-        terms = ellipse_check(...),
+        terms = enquos(...),
         role = role,
         trained = trained,
         lambdas = lambdas,
@@ -128,19 +130,19 @@ prep.step_BoxCox <- function(x, training, info = NULL, ...) {
 
 #' @export
 bake.step_BoxCox <- function(object, new_data, ...) {
-  if (length(object$lambdas) == 0)
-    return(as_tibble(new_data))
   param <- names(object$lambdas)
-  for (i in seq_along(object$lambdas))
-    new_data[, param[i]] <-
-    bc_trans(getElement(new_data, param[i]), lambda = object$lambdas[i])
+
+  for (i in seq_along(object$lambdas)) {
+    new_data[, param[i]] <- bc_trans(getElement(new_data, param[i]), lambda = object$lambdas[i])
+  }
+
   as_tibble(new_data)
 }
 
 print.step_BoxCox <-
   function(x, width = max(20, options()$width - 35), ...) {
-    cat("Box-Cox transformation on ", sep = "")
-    printer(names(x$lambdas), x$terms, x$trained, width = width)
+    title <- "Box-Cox transformation on "
+    print_step(names(x$lambdas), x$terms, x$trained, title, width)
     invisible(x)
   }
 
@@ -176,9 +178,7 @@ ll_bc <- function(lambda, y, gm, eps = .001) {
 
 
 ## eliminates missing data and returns -llh
-bc_obj <- function(lam, dat) {
-  dat <- dat[complete.cases(dat)]
-  geo_mean <- exp(mean(log(dat)))
+bc_obj <- function(lam, dat, geo_mean) {
   ll_bc(lambda = lam, y = dat, gm = geo_mean)
 }
 
@@ -191,15 +191,19 @@ estimate_bc <- function(dat,
   if (length(unique(dat)) < num_unique) {
     rlang::warn("Fewer than `num_unique` values in selected variable.")
     return(NA)
-  } else if (any(dat[complete.cases(dat)] <= 0)) {
+  } else if (any(dat <= 0)) {
     rlang::warn("Non-positive values in selected variable.")
     return(NA)
   }
+
+  geo_mean <- exp(mean(log(dat)))
+
   res <- optimize(
     bc_obj,
     interval = limits,
     maximum = TRUE,
     dat = dat,
+    geo_mean = geo_mean,
     tol = .0001
   )
   lam <- res$maximum
@@ -214,7 +218,7 @@ estimate_bc <- function(dat,
 tidy.step_BoxCox <- function(x, ...) {
   if (is_trained(x)) {
     res <- tibble(terms = names(x$lambdas),
-                  value = x$lambdas)
+                  value = unname(x$lambdas))
   } else {
     term_names <- sel2char(x$terms)
     res <- tibble(terms = term_names,
