@@ -6,23 +6,24 @@
 #' @inheritParams step_center
 #' @param ... Comma separated list of unquoted variable names.
 #'  Use `desc()`` to sort a variable in descending order. See
-#'  [dplyr::arrange()] for more details. For the `tidy`
-#'  method, these are not currently used.
-#' @param role Not used by this step since no new variables are
-#'  created.
+#'  [dplyr::arrange()] for more details.
 #' @param inputs Quosure of values given by `...`.
-#' @return An updated version of `recipe` with the new step
-#'  added to the sequence of existing steps (if any). For the
-#'  `tidy` method, a tibble with columns `terms` which
-#'  contains the sorting variable(s) or expression(s). The
-#'  expressions are text representations and are not parsable.
+#' @template step-return
 #' @details When an object in the user's global environment is
 #'  referenced in the expression defining the new variable(s),
 #'  it is a good idea to use quasiquotation (e.g. `!!!`)
 #'   to embed the value of the object in the expression (to
 #'   be portable between sessions). See the examples.
-#' @keywords datagen
-#' @concept preprocessing
+#'
+#'  # Tidying
+#'
+#'  When you [`tidy()`][tidy.recipe()] this step, a tibble with column
+#'  `terms` which contains the sorting variable(s) or expression(s) is
+#'  returned. The expressions are text representations and are not
+#'  parsable.
+#'
+#' @family row operation steps
+#' @family dplyr steps
 #' @export
 #' @examples
 #' rec <- recipe( ~ ., data = iris) %>%
@@ -121,20 +122,16 @@ bake.step_arrange <- function(object, new_data, ...) {
 
 print.step_arrange <-
   function(x, width = max(20, options()$width - 35), ...) {
-    cat("Row arrangement")
-    if (x$trained) {
-      cat(" [trained]\n")
-    } else {
-      cat("\n")
-    }
+    title <- "Row arrangement using "
+    print_step(x$inputs, x$inputs, x$trained, title, width)
     invisible(x)
   }
 
-#' @rdname step_arrange
-#' @param x A `step_arrange` object
+#' @rdname tidy.recipe
 #' @export
 tidy.step_arrange <- function(x, ...) {
-  cond_expr <- map(x$inputs, quo_get_expr)
+  cond_expr <- unname(x$inputs)
+  cond_expr <- map(cond_expr, quo_get_expr)
   cond_expr <- map_chr(cond_expr, quo_text, width = options()$width, nlines = 1)
   tibble(
     terms = cond_expr,
