@@ -4,15 +4,8 @@
 #'  that will create new columns that are basis expansions of
 #'  variables using B-splines.
 #'
+#' @inheritParams step_pca
 #' @inheritParams step_center
-#' @param ... One or more selector functions to choose which
-#'  variables are affected by the step. See [selections()]
-#'  for more details. For the `tidy` method, these are not
-#'  currently used.
-#' @param role For model terms created by this step, what analysis
-#'  role should they be assigned?. By default, the function assumes
-#'  that the new columns created from the original variables will be
-#'  used as predictors in a model.
 #' @param objects A list of [splines::bs()] objects
 #'  created once the step has been trained.
 #' @param deg_free The degrees of freedom for the spline. As the
@@ -22,13 +15,8 @@
 #' @param degree Degree of polynomial spline (integer).
 #' @param options A list of options for [splines::bs()]
 #'  which should not include `x`, `degree`, or `df`.
-#' @return An updated version of `recipe` with the new step
-#'  added to the sequence of existing steps (if any). For the
-#'  `tidy` method, a tibble with columns `terms` which is
-#'  the columns that will be affected and `holiday`.
-#' @keywords datagen
-#' @concept preprocessing
-#' @concept basis_expansion
+#' @template step-return
+#' @family individual transformation steps
 #' @export
 #' @details `step_bs` can create new features from a single variable
 #'  that enable fitting routines to model this variable in a
@@ -37,6 +25,12 @@
 #'  [splines::bs()]. The original variables are removed
 #'  from the data and new columns are added. The naming convention
 #'  for the new variables is `varname_bs_1` and so on.
+#'
+#'  # Tidying
+#'
+#'  When you [`tidy()`][tidy.recipe()] this step, a tibble with column
+#'  `terms` (the columns that will be affected) is returned.
+#'
 #' @examples
 #' library(modeldata)
 #' data(biomass)
@@ -53,9 +47,6 @@
 #'
 #' expanded <- bake(with_splines, biomass_te)
 #' expanded
-#' @seealso [step_poly()] [recipe()] [step_ns()]
-#'   [prep.recipe()] [bake.recipe()]
-
 step_bs <-
   function(recipe,
            ...,
@@ -71,7 +62,7 @@ step_bs <-
     add_step(
       recipe,
       step_bs_new(
-        terms = ellipse_check(...),
+        terms = enquos(...),
         trained = trained,
         deg_free = deg_free,
         degree = degree,
@@ -138,15 +129,18 @@ bs_predict <- function(object, x) {
 
 #' @export
 prep.step_bs <- function(x, training, info = NULL, ...) {
-  col_names <- eval_select_recipes(x$terms, training, info)
+  col_names <- recipes_eval_select(x$terms, training, info)
   check_type(training[, col_names])
 
   opt <- x$options
   opt$df <- x$deg_free
   opt$degree <- x$degree
   obj <- lapply(training[, col_names], bs_statistics, opt)
-  for (i in seq(along.with = col_names))
+
+  for (i in seq(along.with = col_names)) {
     attr(obj[[i]], "var") <- col_names[i]
+  }
+
   step_bs_new(
     terms = x$terms,
     role = x$role,
@@ -188,28 +182,26 @@ bake.step_bs <- function(object, new_data, ...) {
 
 print.step_bs <-
   function(x, width = max(20, options()$width - 28), ...) {
-    cat("B-Splines on ")
-    printer(names(x$objects), x$terms, x$trained, width = width)
+    title <- "B-splines on "
+    print_step(names(x$objects), x$terms, x$trained, title, width)
     invisible(x)
   }
 
-#' @rdname step_bs
-#' @param x A `step_bs` object.
+#' @rdname tidy.recipe
 #' @export
 tidy.step_bs <- function(x, ...) {
   if (is_trained(x)) {
-    cols <- tibble(terms = names(x$objects))
+    res <- tibble(terms = names(x$objects))
   } else {
     cols <- sel2char(x$terms)
+    res <- tibble(terms = cols)
   }
-  res <- expand.grid(terms = cols, stringsAsFactors = FALSE)
   res$id <- x$id
   as_tibble(res)
 }
 
 # ------------------------------------------------------------------------------
 
-#' @rdname tunable.step
 #' @export
 tunable.step_bs <- function(x, ...) {
   tibble::tibble(
