@@ -5,33 +5,26 @@
 #'
 #' @param recipe A recipe object. The step will be added to the
 #'  sequence of operations for this recipe.
-#' @param ... One or more selector functions to choose which
-#'  variables are affected by the step. See [selections()]
-#'  for more details. For the `tidy` method, these are not
-#'  currently used.
+#' @param ... One or more selector functions to choose variables
+#'  for this step. See [selections()] for more details.
 #' @param role Not used by this step since no new variables are
 #'  created.
 #' @param trained A logical to indicate if the quantities for
 #'  preprocessing have been estimated.
 #' @param means A named numeric vector of means. This is
-#'  `NULL` until computed by [prep.recipe()].
+#'  `NULL` until computed by [prep()].
 #' @param na_rm A logical value indicating whether `NA`
 #'  values should be removed during computations.
 #' @param skip A logical. Should the step be skipped when the
-#'  recipe is baked by [bake.recipe()]? While all operations are baked
-#'  when [prep.recipe()] is run, some operations may not be able to be
+#'  recipe is baked by [bake()]? While all operations are baked
+#'  when [prep()] is run, some operations may not be able to be
 #'  conducted on new data (e.g. processing the outcome variable(s)).
 #'  Care should be taken when using `skip = TRUE` as it may affect
-#'  the computations for subsequent operations
+#'  the computations for subsequent operations.
 #' @param id A character string that is unique to this step to identify it.
-#' @return An updated version of `recipe` with the new step
-#'  added to the sequence of existing steps (if any). For the
-#'  `tidy` method, a tibble with columns `terms` (the
-#'  selectors or variables selected) and `value` (the means).
+#' @template step-return
 #'
-#' @keywords datagen
-#' @concept preprocessing
-#' @concept normalization_methods
+#' @family normalization steps
 #' @export
 #' @details Centering data means that the average of a variable is
 #'  subtracted from the data. `step_center` estimates the
@@ -39,7 +32,14 @@
 #'  argument of `prep.recipe`. `bake.recipe` then applies
 #'  the centering to new data sets using these means.
 #'
+#'  # Tidying
+#'
+#'  When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
+#'  `terms` (the selectors or variables selected) and `value` (the means)
+#'  is returned.
+#'
 #' @examples
+#' library(modeldata)
 #' data(biomass)
 #'
 #' biomass_tr <- biomass[biomass$dataset == "Training",]
@@ -60,8 +60,6 @@
 #'
 #' tidy(center_trans, number = 1)
 #' tidy(center_obj, number = 1)
-#' @seealso [recipe()] [prep.recipe()]
-#'   [bake.recipe()]
 step_center <-
   function(recipe,
            ...,
@@ -74,7 +72,7 @@ step_center <-
     add_step(
       recipe,
       step_center_new(
-        terms = ellipse_check(...),
+        terms = enquos(...),
         trained = trained,
         role = role,
         means = means,
@@ -100,8 +98,9 @@ step_center_new <-
     )
   }
 
+#' @export
 prep.step_center <- function(x, training, info = NULL, ...) {
-  col_names <- terms_select(x$terms, info = info)
+  col_names <- recipes_eval_select(x$terms, training, info)
   check_type(training[, col_names])
 
   means <-
@@ -117,30 +116,29 @@ prep.step_center <- function(x, training, info = NULL, ...) {
   )
 }
 
+#' @export
 bake.step_center <- function(object, new_data, ...) {
   res <-
     sweep(as.matrix(new_data[, names(object$means)]), 2, object$means, "-")
-  if (is.matrix(res) && ncol(res) == 1)
-    res <- res[, 1]
+  res <- tibble::as_tibble(res)
   new_data[, names(object$means)] <- res
   as_tibble(new_data)
 }
 
 print.step_center <-
   function(x, width = max(20, options()$width - 30), ...) {
-    cat("Centering for ", sep = "")
-    printer(names(x$means), x$terms, x$trained, width = width)
+    title <- "Centering for "
+    print_step(names(x$means), x$terms, x$trained, title, width)
     invisible(x)
   }
 
 
-#' @rdname step_center
-#' @param x A `step_center` object.
+#' @rdname tidy.recipe
 #' @export
 tidy.step_center <- function(x, ...) {
   if (is_trained(x)) {
     res <- tibble(terms = names(x$means),
-                  value = x$means)
+                  value = unname(x$means))
   } else {
     term_names <- sel2char(x$terms)
     res <- tibble(terms = term_names,
