@@ -5,16 +5,10 @@
 #'  distance measurements to the data centroid. This is done for
 #'  each value of a categorical class variable.
 #'
+#' @inheritParams step_pca
 #' @inheritParams step_center
-#' @param ... One or more selector functions to choose which
-#'  variables are affected by the step. See [selections()]
-#'  for more details. For the `tidy` method, these are not
-#'  currently used.
 #' @param class A single character string that specifies a single
 #'  categorical variable to be used as the class.
-#' @param role For model terms created by this step, what analysis
-#'  role should they be assigned?. By default, the function assumes
-#'  that resulting distances will be used as predictors in a model.
 #' @param mean_func A function to compute the center of the
 #'  distribution.
 #' @param cov_func A function that computes the covariance matrix
@@ -22,18 +16,10 @@
 #'  by pooling the data for all of the classes?
 #' @param log A logical: should the distances be transformed by
 #'  the natural log function?
-#' @param prefix A character string that defines the naming convention for
-#'  new distance columns. Defaults to `"classdist_"`. See Details below.
 #' @param objects Statistics are stored here once this step has
-#'  been trained by [prep.recipe()].
-#' @return An updated version of `recipe` with the new step
-#'  added to the sequence of existing steps (if any). For the
-#'  `tidy` method, a tibble with columns `terms` (the
-#'  selectors or variables selected), `value` (the centroid of
-#'  the class), and `class`.
-#' @keywords datagen
-#' @concept preprocessing
-#' @concept dimension_reduction
+#'  been trained by [prep()].
+#' @template step-return
+#' @family multivariate transformation steps
 #' @export
 #' @details `step_classdist` will create a new column for every
 #'  unique value of the `class` variable.
@@ -46,6 +32,13 @@
 #'  listed in the `terms` argument. If `pool = TRUE`,
 #'  there must be at least as many data points are variables
 #'  overall.
+#'
+#' # Tidying
+#'
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
+#' `terms` (the selectors or variables selected), `value` (the centroid
+#' of the class), and `class` is returned.
+#'
 #' @examples
 #'
 #' # in case of missing data...
@@ -88,7 +81,7 @@ step_classdist <- function(recipe,
   add_step(
     recipe,
     step_classdist_new(
-      terms = ellipse_check(...),
+      terms = enquos(...),
       class = class,
       role = role,
       trained = trained,
@@ -125,7 +118,8 @@ step_classdist_new <-
   }
 
 get_center <- function(x, mfun = mean) {
-  apply(x, 2, mfun)
+  x <- tibble::as_tibble(x)
+  vapply(x, FUN = mfun, FUN.VALUE = numeric(1))
 }
 get_both <- function(x, mfun = mean, cfun = cov) {
   list(center = get_center(x, mfun),
@@ -135,7 +129,7 @@ get_both <- function(x, mfun = mean, cfun = cov) {
 #' @export
 prep.step_classdist <- function(x, training, info = NULL, ...) {
   class_var <- x$class[1]
-  x_names <- eval_select_recipes(x$terms, training, info)
+  x_names <- recipes_eval_select(x$terms, training, info)
   check_type(training[, x_names])
 
   x_dat <-
@@ -169,11 +163,23 @@ prep.step_classdist <- function(x, training, info = NULL, ...) {
   )
 }
 
-mah_by_class <- function(param, x)
+mah_by_class <- function(param, x) {
+  if (ncol(x) == 0L) {
+    # mahalanobis() can't handle 0 column case
+    return(rep(NA_real_, nrow(x)))
+  }
+
   mahalanobis(x, param$center, param$scale)
+}
+
+mah_pooled <- function(means, x, cov_mat) {
+  if (ncol(x) == 0L) {
+    # mahalanobis() can't handle 0 column case
+    return(rep(NA_real_, nrow(x)))
+  }
 
-mah_pooled <- function(means, x, cov_mat)
   mahalanobis(x, means, cov_mat)
+}
 
 
 #' @export
@@ -204,14 +210,14 @@ bake.step_classdist <- function(object, new_data, ...) {
 
 print.step_classdist <-
   function(x, width = max(20, options()$width - 30), ...) {
-    cat("Distances to", x$class, "for ")
+    title <- glue::glue("Distances to {x$class} for ")
     if (x$trained) {
       x_names <- if (x$pool)
         names(x$objects[["center"]][[1]])
       else
         names(x$objects[[1]]$center)
     } else x_names <- NULL
-    printer(x_names, x$terms, x$trained, width = width)
+    print_step(x_names, x$terms, x$trained, title, width)
     invisible(x)
   }
 
@@ -221,13 +227,19 @@ get_centroid <- function(x) {
   tibble(terms = names(x$center),
          value = unname(x$center))
 }
+get_centroid_pool <- function(x) {
+  tibble(terms = names(x), value = unname(x))
+}
 
-#' @rdname step_classdist
-#' @param x A `step_classdist` object.
+#' @rdname tidy.recipe
 #' @export
 tidy.step_classdist <- function(x, ...) {
   if (is_trained(x)) {
-    centroids <- lapply(x$objects, get_centroid)
+    if (x$pool) {
+      centroids <- lapply(x$objects$center, get_centroid_pool)
+    } else {
+      centroids <- lapply(x$objects, get_centroid)
+    }
     num_rows <- vapply(centroids, nrow, numeric(1))
     classes <- rep(names(centroids), num_rows)
     res <- dplyr::bind_rows(centroids)
