@@ -5,12 +5,6 @@
 #'  absolute correlations with other variables.
 #'
 #' @inheritParams step_center
-#' @param ... One or more selector functions to choose which
-#'  variables are affected by the step. See [selections()]
-#'  for more details. For the `tidy` method, these are not
-#'  currently used.
-#' @param role Not used by this step since no new variables are
-#'  created.
 #' @param threshold A value for the threshold of absolute
 #'  correlation values. The step will try to remove the minimum
 #'  number of columns so that all the resulting absolute
@@ -21,18 +15,14 @@
 #'  to the [stats::cor()] function.
 #' @param removals A character string that contains the names of
 #'  columns that should be removed. These values are not determined
-#'  until [prep.recipe()] is called.
-#' @return An updated version of `recipe` with the new step
-#'  added to the sequence of existing steps (if any). For the
-#'  `tidy` method, a tibble with columns `terms` which
-#'  is the columns that will be removed.
-#' @keywords datagen
+#'  until [prep()] is called.
+#' @template step-return
+#' @template filter-steps
 #' @author Original R code for filtering algorithm by Dong Li,
 #'  modified by Max Kuhn. Contributions by Reynald Lescarbeau (for
 #'  original in `caret` package). Max Kuhn for the `step`
 #'  function.
-#' @concept preprocessing
-#' @concept variable_filters
+#' @family variable filter steps
 #' @export
 #'
 #' @details This step attempts to remove variables to keep the
@@ -44,6 +34,11 @@
 #'  has sporadic missing values (and an inappropriate value of `use`
 #'  is chosen), some columns will also be excluded from the filter.
 #'
+#' # Tidying
+#'
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble with column
+#' `terms` (the columns that will be removed) is returned.
+#'
 #' @examples
 #' library(modeldata)
 #' data(biomass)
@@ -69,9 +64,6 @@
 #'
 #' tidy(corr_filter, number = 1)
 #' tidy(filter_obj, number = 1)
-#' @seealso [step_nzv()] [recipe()]
-#'   [prep.recipe()] [bake.recipe()]
-
 step_corr <- function(recipe,
                       ...,
                       role = NA,
@@ -86,7 +78,7 @@ step_corr <- function(recipe,
   add_step(
     recipe,
     step_corr_new(
-      terms = ellipse_check(...),
+      terms = enquos(...),
       role = role,
       trained = trained,
       threshold = threshold,
@@ -117,7 +109,7 @@ step_corr_new <-
 
 #' @export
 prep.step_corr <- function(x, training, info = NULL, ...) {
-  col_names <- eval_select_recipes(x$terms, training, info)
+  col_names <- recipes_eval_select(x$terms, training, info)
   check_type(training[, col_names])
 
   if (length(col_names) > 1) {
@@ -128,7 +120,7 @@ prep.step_corr <- function(x, training, info = NULL, ...) {
       method = x$method
     )
   } else {
-    filter <- numeric(0)
+    filter <- character(0)
   }
 
   step_corr_new(
@@ -153,20 +145,8 @@ bake.step_corr <- function(object, new_data, ...) {
 
 print.step_corr <-
   function(x,  width = max(20, options()$width - 36), ...) {
-    if (x$trained) {
-      if (length(x$removals) > 0) {
-        cat("Correlation filter removed ")
-        cat(format_ch_vec(x$removals, width = width))
-      } else
-        cat("Correlation filter removed no terms")
-    } else {
-      cat("Correlation filter on ", sep = "")
-      cat(format_selectors(x$terms, width = width))
-    }
-    if (x$trained)
-      cat(" [trained]\n")
-    else
-      cat("\n")
+    title <- "Correlation filter on "
+    print_step(x$removals, x$terms, x$trained, title, width)
     invisible(x)
   }
 
@@ -229,24 +209,19 @@ corr_filter <-
 
 tidy_filter <- function(x, ...) {
   if (is_trained(x)) {
-    res <- tibble(terms = x$removals)
+    res <- tibble(terms = unname(x$removals))
   } else {
     term_names <- sel2char(x$terms)
-    res <- tibble(terms = na_chr)
+    res <- tibble(terms = term_names)
   }
   res$id <- x$id
   res
 }
 
-#' @rdname step_corr
-#' @param x A `step_corr` object.
+#' @rdname tidy.recipe
 #' @export
 tidy.step_corr <- tidy_filter
 
-
-
-
-#' @rdname tunable.step
 #' @export
 tunable.step_corr <- function(x, ...) {
   tibble::tibble(
