@@ -4,17 +4,11 @@
 #'  step that will create a variable that counts instances of a
 #'  regular expression pattern in text.
 #'
+#' @inheritParams step_pca
 #' @inheritParams step_center
-#' @inherit step_center return
-#' @param ... A single selector functions to choose which variable
-#'  will be searched for the pattern. The selector should resolve
-#'  into a single variable. See [selections()] for more
-#'  details. For the `tidy` method, these are not
-#'  currently used.
-#' @param role For a variable created by this step, what analysis
-#'  role should they be assigned?. By default, the function assumes
-#'  that the new dummy variable column created by the original
-#'  variable will be used as a predictor in a model.
+#' @param ... A single selector function to choose which variable
+#'  will be searched for the regex pattern. The selector should
+#'  resolve to a single variable. See [selections()] for more details.
 #' @param pattern A character string containing a regular
 #'  expression (or character string for `fixed = TRUE`) to be
 #'  matched in the given character vector. Coerced by
@@ -27,16 +21,17 @@
 #'  variable. It should be a valid column name.
 #' @param input A single character value for the name of the
 #'  variable being searched. This is `NULL` until computed by
-#'  [prep.recipe()].
-#' @return An updated version of `recipe` with the new step
-#'  added to the sequence of existing steps (if any). For the
-#'  `tidy` method, a tibble with columns `terms` (the
-#'  selectors or variables selected) and `result` (the
-#'  new column name).
-#' @keywords datagen
-#' @concept preprocessing
-#' @concept dummy_variables
-#' @concept regular_expressions
+#'  [prep()].
+#' @template step-return
+#' @details
+#'
+#' # Tidying
+#'
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
+#' `terms` (the selectors or variables selected) and `result` (the
+#' new column name) is returned.
+#'
+#' @family dummy variable and encoding steps
 #' @export
 #' @examples
 #' library(modeldata)
@@ -74,7 +69,7 @@ step_count <- function(recipe,
     rlang::abort(paste0("Valid options are: ",
                         paste0(valid_args, collapse = ", ")))
 
-  terms <- ellipse_check(...)
+  terms <- enquos(...)
   if (length(terms) > 1)
     rlang::abort("For this step, only a single selector can be used.")
 
@@ -114,9 +109,9 @@ step_count_new <-
 
 #' @export
 prep.step_count <- function(x, training, info = NULL, ...) {
-  col_name <- eval_select_recipes(x$terms, training, info)
-  if (length(col_name) != 1)
-    rlang::abort("The selector should only select a single variable")
+  col_name <- recipes_eval_select(x$terms, training, info)
+  if (length(col_name) > 1)
+    rlang::abort("The selector should select at most a single variable")
   if (any(info$type[info$variable %in% col_name] != "nominal"))
     rlang::abort("The regular expression input should be character or factor")
 
@@ -135,6 +130,12 @@ prep.step_count <- function(x, training, info = NULL, ...) {
 }
 
 bake.step_count <- function(object, new_data, ...) {
+  if (length(object$input) == 0L) {
+    # Empty selection, but still return the new column
+    new_data[, object$result] <- if (object$normalize) NA_real_ else NA_integer_
+    return(new_data)
+  }
+
   ## sub in options
   regex <- expr(
     gregexpr(
@@ -162,20 +163,13 @@ counter <- function(x) length(x[x > 0])
 
 print.step_count <-
   function(x, width = max(20, options()$width - 30), ...) {
-    cat("Regular expression counts using `",
-        x$pattern,
-        "`",
-        sep = "")
-    if (x$trained)
-      cat(" [trained]\n")
-    else
-      cat("\n")
+    title <- "Regular expression counts using "
+    print_step(x$input, x$terms, x$trained, title, width)
     invisible(x)
   }
 
 
-#' @rdname step_count
-#' @param x A `step_count` object.
+#' @rdname tidy.recipe
 #' @export
 tidy.step_count <- function(x, ...) {
   term_names <- sel2char(x$terms)
