@@ -4,17 +4,11 @@
 #'  step that will convert date data into one or more factor or
 #'  numeric variables.
 #'
+#' @inheritParams step_pca
 #' @inheritParams step_center
-#' @inherit step_center return
-#' @param ... One or more selector functions to choose which
-#'  variables that will be used to create the new variables. The
-#'  selected variables should have class `Date` or
+#' @param ... One or more selector functions to choose variables
+#'  for this step. The selected variables should have class `Date` or
 #'  `POSIXct`. See [selections()] for more details.
-#'  For the `tidy` method, these are not currently used.
-#' @param role For model terms created by this step, what analysis
-#'  role should they be assigned?. By default, the function assumes
-#'  that the new variable columns created by the original variables
-#'  will be used as predictors in a model.
 #' @param features A character string that includes at least one
 #'  of the following values: `month`, `dow` (day of week),
 #'  `doy` (day of year), `week`, `month`,
@@ -35,24 +29,22 @@
 #'  available for features `month` or `dow`.
 #' @param columns A character string of variables that will be
 #'  used as inputs. This field is a placeholder and will be
-#'  populated once [prep.recipe()] is used.
+#'  populated once [prep()] is used.
 #' @param keep_original_cols A logical to keep the original variables in the
 #'  output. Defaults to `TRUE`.
-#' @return For `step_date`, an updated version of recipe with
-#'  the new step added to the sequence of existing steps (if any).
-#'  For the `tidy` method, a tibble with columns `terms`
-#'  (the selectors or variables selected), `value` (the feature
-#'  names), and `ordinal` (a logical).
-#' @keywords datagen
-#' @concept preprocessing
-#' @concept model_specification
-#' @concept variable_encodings
-#' @concept dates
+#' @template step-return
+#' @family dummy variable and encoding steps
 #' @export
 #' @details Unlike some other steps, `step_date` does *not*
 #'  remove the original date variables by default. Set `keep_original_cols`
 #'  to `FALSE` to remove them.
 #'
+#'  # Tidying
+#'
+#'  When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
+#'  `terms` (the selectors or variables selected), `value` (the feature
+#'  names), and `ordinal` (a logical) is returned.
+#'
 #' @examples
 #' library(lubridate)
 #'
@@ -70,9 +62,6 @@
 #'
 #' tidy(date_rec, number = 1)
 #'
-#' @seealso [step_holiday()] [step_rm()]
-#'   [recipe()] [prep.recipe()]
-#'   [bake.recipe()]
 step_date <-
   function(recipe,
            ...,
@@ -98,14 +87,14 @@ step_date <-
       "month")
   if (!is_tune(features) & !is_varying(features)) {
     if (!all(features %in% feat)) {
-      rlang::abort("Possible values of `features` should include: ",
-           paste0("'", feat, "'", collapse = ", "))
+      rlang::abort(paste0("Possible values of `features` should include: ",
+           paste0("'", feat, "'", collapse = ", ")))
     }
   }
   add_step(
     recipe,
     step_date_new(
-      terms = ellipse_check(...),
+      terms = enquos(...),
       role = role,
       trained = trained,
       features = features,
@@ -142,7 +131,7 @@ step_date_new <-
 
 #' @export
 prep.step_date <- function(x, training, info = NULL, ...) {
-  col_names <- eval_select_recipes(x$terms, training, info)
+  col_names <- recipes_eval_select(x$terms, training, info)
 
   date_data <- info[info$variable %in% col_names, ]
   if (any(date_data$type != "date"))
@@ -271,18 +260,17 @@ bake.step_date <- function(object, new_data, ...) {
 
 print.step_date <-
   function(x, width = max(20, options()$width - 29), ...) {
-    cat("Date features from ")
-    printer(x$columns, x$terms, x$trained, width = width)
+    title <- "Date features from "
+    print_step(x$columns, x$terms, x$trained, title, width)
     invisible(x)
   }
 
-#' @rdname step_date
-#' @param x A `step_date` object.
+#' @rdname tidy.recipe
 #' @export
 tidy.step_date <- function(x, ...) {
   if (is_trained(x)) {
     res <- tidyr::crossing(
-      terms = x$columns,
+      terms = unname(x$columns),
       value = x$features,
       ordinal = x$ordinal
     )
