@@ -37,10 +37,6 @@ discretize.default <- function(x, ...)
 #' @return `discretize` returns an object of class
 #'  `discretize` and `predict.discretize` returns a factor
 #'  vector.
-#' @keywords datagen
-#' @concept preprocessing
-#' @concept discretization
-#' @concept factors
 #' @export
 #' @details `discretize` estimates the cut points from
 #'  `x` using percentiles. For example, if `cuts = 3`, the
@@ -74,13 +70,6 @@ discretize.default <- function(x, ...)
 #'
 #' carbon_no_infs <- discretize(biomass_tr$carbon, infs = FALSE)
 #' predict(carbon_no_infs, c(50, 100))
-#'
-#' rec <- recipe(HHV ~ carbon + hydrogen + oxygen + nitrogen + sulfur,
-#'               data = biomass_tr)
-#' rec <- rec %>% step_discretize(carbon, hydrogen)
-#' rec <- prep(rec, biomass_tr)
-#' binned_te <- bake(rec, biomass_te)
-#' table(binned_te$carbon)
 
 discretize.numeric <-
   function(x,
@@ -214,8 +203,6 @@ print.discretize <-
 #'  on a training set).
 #'
 #' @inheritParams step_center
-#' @param role Not used by this step since no new variables are
-#'  created.
 #' @param num_breaks An integer defining how many cuts to make of the
 #'  data.
 #' @param min_unique An integer defining a sample size line of
@@ -224,23 +211,39 @@ print.discretize <-
 #'  discretization takes place.
 #' @param objects The [discretize()] objects are stored
 #'  here once the recipe has be trained by
-#'  [prep.recipe()].
+#'  [prep()].
 #' @param options A list of options to [discretize()]. A
 #'  default is set for the argument `x`. Note that using
 #'  the options `prefix` and `labels` when more than one
 #'  variable is being transformed might be problematic as all
 #'  variables inherit those values.
-#' @param ... For `step_discretize`, the dots specify
-#'  one or more selector functions to choose which variables are
-#'  affected by the step. See [selections()] for more
-#'  details. For the `tidy` method, these are not currently
-#'  used.
-#' @return `step_discretize` returns an updated version of
-#'  `recipe` with the new step added to the sequence of
-#'  existing steps (if any). For the `tidy` method, a tibble
-#'  with columns `terms` (the selectors or variables selected)
-#'  and `value` (the breaks).
+#' @template step-return
+#' @details
+#'
+#' # Tidying
+#'
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
+#' `terms` (the selectors or variables selected) and `value`
+#' (the breaks) is returned.
+#' @family discretization steps
 #' @export
+#'
+#' @examples
+#' library(modeldata)
+#' data(biomass)
+#'
+#' biomass_tr <- biomass[biomass$dataset == "Training",]
+#' biomass_te <- biomass[biomass$dataset == "Testing",]
+#'
+#' rec <- recipe(HHV ~ carbon + hydrogen + oxygen + nitrogen + sulfur,
+#'               data = biomass_tr) %>%
+#'   step_discretize(carbon, hydrogen)
+#'
+#' rec <- prep(rec, biomass_tr)
+#' binned_te <- bake(rec, biomass_te)
+#' table(binned_te$carbon)
+#'
+#' tidy(rec, 1)
 
 step_discretize <- function(recipe,
                             ...,
@@ -261,7 +264,7 @@ step_discretize <- function(recipe,
   add_step(
     recipe,
     step_discretize_new(
-      terms = ellipse_check(...),
+      terms = enquos(...),
       trained = trained,
       role = role,
       num_breaks = num_breaks,
@@ -300,7 +303,7 @@ bin_wrapper <- function(x, args) {
 
 #' @export
 prep.step_discretize <- function(x, training, info = NULL, ...) {
-  col_names <- terms_select(x$terms, info = info)
+  col_names <- recipes_eval_select(x$terms, training, info)
   check_type(training[, col_names])
 
   if (length(col_names) > 1 & any(names(x$options) %in% c("prefix", "labels"))) {
@@ -339,22 +342,24 @@ bake.step_discretize <- function(object, new_data, ...) {
 
 print.step_discretize <-
   function(x, width = max(20, options()$width - 30), ...) {
-    cat("Dummy variables from ")
-    printer(names(x$objects), x$terms, x$trained, width = width)
+    title <- "Discretize numeric variables from "
+    print_step(names(x$objects), x$terms, x$trained, title, width)
     invisible(x)
   }
 
-#' @rdname step_discretize
-#' @param x A `step_discretize` object
+#' @rdname tidy.recipe
 #' @export
 tidy.step_discretize <- function(x, ...) {
   if (is_trained(x)) {
-    brks <- lapply(x$objects,
-                   function(x) x$breaks)
+    brks <- lapply(x$objects, function(x) x$breaks)
     num_brks <- vapply(brks, length, c(1L))
     brk_vars <- rep(names(num_brks), num_brks)
 
-    res <- tibble(terms = brk_vars, value = unname(unlist(brks)))
+    brks <- unname(brks)
+    brks <- lapply(brks, unname)
+    values <- vctrs::vec_unchop(brks, ptype = double())
+
+    res <- tibble(terms = brk_vars, value = values)
   } else {
     term_names <- sel2char(x$terms)
     res <- tibble(terms = term_names, value = na_dbl)
@@ -363,9 +368,6 @@ tidy.step_discretize <- function(x, ...) {
   res
 }
 
-
-
-#' @rdname tunable.step
 #' @export
 tunable.step_discretize <- function(x, ...) {
   tibble::tibble(
