@@ -3,35 +3,28 @@
 #' `step_filter` creates a *specification* of a recipe step
 #'  that will remove rows using [dplyr::filter()].
 #'
+#' @template row-ops
 #' @inheritParams step_center
 #' @param ... Logical predicates defined in terms of the variables
 #'  in the data. Multiple conditions are combined with `&`. Only
 #'  rows where the condition evaluates to `TRUE` are kept. See
-#'  [dplyr::filter()] for more details. For the `tidy`
-#'  method, these are not currently used.
-#' @param role Not used by this step since no new variables are
-#'  created.
+#'  [dplyr::filter()] for more details.
 #' @param inputs Quosure of values given by `...`.
-#' @param skip A logical. Should the step be skipped when the
-#'  recipe is baked by [bake.recipe()]? While all operations are baked
-#'  when [prep.recipe()] is run, some operations may not be able to be
-#'  conducted on new data (e.g. processing the outcome variable(s)).
-#'  Care should be taken when using `skip = FALSE`; in most instances that
-#'  affect the rows of the data being predicted, this step probably should not
-#'  be applied.
-#' @return An updated version of `recipe` with the new step
-#'  added to the sequence of existing steps (if any). For the
-#'  `tidy` method, a tibble with columns `terms` which
-#'  contains the conditional statements. These
-#'  expressions are text representations and are not parsable.
+#' @template step-return
 #' @details When an object in the user's global environment is
 #'  referenced in the expression defining the new variable(s),
 #'  it is a good idea to use quasiquotation (e.g. `!!`) to embed
 #'  the value of the object in the expression (to be portable
 #'  between sessions). See the examples.
-#' @keywords datagen
-#' @concept preprocessing
-#' @concept row_filters
+#'
+#'  # Tidying
+#'
+#'  When you [`tidy()`][tidy.recipe()] this step, a tibble with column
+#'  `terms` which contains the conditional statements is returned.
+#'  These expressions are text representations and are not parsable.
+#'
+#' @family row operation steps
+#' @family dplyr steps
 #' @export
 #' @examples
 #' rec <- recipe( ~ ., data = iris) %>%
@@ -66,7 +59,6 @@
 #'   step_filter(Sepal.Length > 4.5, Species  %in% !!values)
 #'
 #' tidy(qq_rec, number = 1)
-
 step_filter <- function(
   recipe, ...,
   role = NA,
@@ -124,20 +116,15 @@ bake.step_filter <- function(object, new_data, ...) {
 
 print.step_filter <-
   function(x, width = max(20, options()$width - 35), ...) {
-    cat("Row filtering")
-    if (x$trained) {
-      cat(" [trained]\n")
-    } else {
-      cat("\n")
-    }
+    title <- "Row filtering using "
+    print_step(x$inputs, x$inputs, x$trained, title, width)
     invisible(x)
   }
 
-#' @rdname step_filter
-#' @param x A `step_filter` object
+#' @rdname tidy.recipe
 #' @export
 tidy.step_filter <- function(x, ...) {
-  cond_expr <- map(x$inputs, quo_get_expr)
+  cond_expr <- map(unname(x$inputs), quo_get_expr)
   cond_expr <- map_chr(cond_expr, quo_text, width = options()$width, nlines = 1)
   tibble(
     terms = cond_expr,
