@@ -4,39 +4,28 @@
 #'  recipe step that will convert date data into one or more binary
 #'  indicator variables for common holidays.
 #'
+#' @inheritParams step_date
+#' @inheritParams step_pca
 #' @inheritParams step_center
-#' @inherit step_center return
-#' @param ... One or more selector functions to choose which
-#'  variables will be used to create the new variables. The selected
-#'  variables should have class `Date` or `POSIXct`. See
-#'  [selections()] for more details. For the `tidy`
-#'  method, these are not currently used.
-#' @param role For model terms created by this step, what analysis
-#'  role should they be assigned?. By default, the function assumes
-#'  that the new variable columns created by the original variables
-#'  will be used as predictors in a model.
 #' @param holidays A character string that includes at least one
 #'  holiday supported by the `timeDate` package. See
 #'  [timeDate::listHolidays()] for a complete list.
 #' @param columns A character string of variables that will be
 #'  used as inputs. This field is a placeholder and will be
-#'  populated once [prep.recipe()] is used.
-#' @param keep_original_cols A logical to keep the original variables in the
-#'  output. Defaults to `TRUE`.
-#' @return An updated version of `recipe` with the new step
-#'  added to the sequence of existing steps (if any). For the
-#'  `tidy` method, a tibble with columns `terms` which is
-#'  the columns that will be affected and `holiday`.
-#' @keywords datagen
-#' @concept preprocessing
-#' @concept model_specification
-#' @concept variable_encodings
-#' @concept dates
+#'  populated once [prep()] is used.
+#' @template step-return
+#' @family dummy variable and encoding steps
+#' @seealso [timeDate::listHolidays()]
 #' @export
 #' @details Unlike some other steps, `step_holiday` does *not*
 #'  remove the original date variables by default. Set `keep_original_cols`
 #'  to `FALSE` to remove them.
 #'
+#'  # Tidying
+#'
+#'  When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
+#'  `terms` (the columns that will be affected) and `holiday` is returned.
+#'
 #' @examples
 #' library(lubridate)
 #'
@@ -47,9 +36,6 @@
 #' holiday_rec <- prep(holiday_rec, training = examples)
 #' holiday_values <- bake(holiday_rec, new_data = examples)
 #' holiday_values
-#' @seealso [step_date()] [step_rm()]
-#'   [recipe()] [prep.recipe()]
-#'   [bake.recipe()] [timeDate::listHolidays()]
 #' @import timeDate
 step_holiday <-
   function(
@@ -73,7 +59,7 @@ step_holiday <-
   add_step(
     recipe,
     step_holiday_new(
-      terms = ellipse_check(...),
+      terms = enquos(...),
       role = role,
       trained = trained,
       holidays = holidays,
@@ -102,7 +88,7 @@ step_holiday_new <-
 
 #' @export
 prep.step_holiday <- function(x, training, info = NULL, ...) {
-  col_names <- eval_select_recipes(x$terms, training, info)
+  col_names <- recipes_eval_select(x$terms, training, info)
 
   holiday_data <- info[info$variable %in% col_names, ]
   if (any(holiday_data$type != "date"))
@@ -168,19 +154,16 @@ bake.step_holiday <- function(object, new_data, ...) {
 
 print.step_holiday <-
   function(x, width = max(20, options()$width - 29), ...) {
-    cat("Holiday features from ")
-    printer(x$columns, x$terms, x$trained, width = width)
+    title <- "Holiday features from "
+    print_step(x$columns, x$terms, x$trained, title, width)
     invisible(x)
   }
 
-#' @rdname step_holiday
-#' @param x A `step_holiday` object.
+#' @rdname tidy.recipe
 #' @export
 tidy.step_holiday <- function(x, ...) {
   res <- simple_terms(x, ...)
-  res <- expand.grid(terms = res$terms,
-                     holiday = x$holidays,
-                     stringsAsFactors = FALSE)
+  res <- tidyr::expand_grid(terms = res$terms, holiday = x$holidays)
   res$id <- x$id
-  as_tibble(res)
+  res
 }
