@@ -4,40 +4,21 @@
 #'  that will convert numeric data into one or more independent
 #'  components.
 #'
+#' @inheritParams step_pca
 #' @inheritParams step_center
-#' @inherit step_center return
-#' @param ... One or more selector functions to choose which
-#'  variables will be used to compute the components. See
-#'  [selections()] for more details. For the `tidy`
-#'  method, these are not currently used.
-#' @param role For model terms created by this step, what analysis
-#'  role should they be assigned?. By default, the function assumes
-#'  that the new independent component columns created by the
-#'  original variables will be used as predictors in a model.
-#' @param num_comp The number of ICA components to retain as new
-#'  predictors. If `num_comp` is greater than the number of columns
-#'  or the number of possible components, a smaller value will be
-#'  used.
 #' @param options A list of options to
 #'  [fastICA::fastICA()]. No defaults are set here.
 #'  **Note** that the arguments `X` and `n.comp` should
 #'  not be passed here.
+#' @param seed A single integer to set the random number stream prior to
+#'  running ICA.
 #' @param res The [fastICA::fastICA()] object is stored
 #'  here once this preprocessing step has be trained by
-#'  [prep.recipe()].
-#' @param keep_original_cols A logical to keep the original variables in the
-#'  output. Defaults to `FALSE`.
-#' @param prefix A character string that will be the prefix to the
-#'  resulting new variables. See notes below.
-#' @return An updated version of `recipe` with the new step
-#'  added to the sequence of existing steps (if any). For the
-#'  `tidy` method, a tibble with columns `terms` (the
-#'  selectors or variables selected), `value` (the loading),
-#'  and `component`.
-#' @keywords datagen
-#' @concept preprocessing
-#' @concept ica
-#' @concept projection_methods
+#'  [prep()].
+#' @param columns A character string of variable names that will
+#'  be populated elsewhere.
+#' @template step-return
+#' @family multivariate transformation steps
 #' @export
 #' @details Independent component analysis (ICA) is a
 #'  transformation of a group of variables that produces a new set
@@ -64,6 +45,12 @@
 #'  If `num_comp = 101`, the names would be `IC001` -
 #'  `IC101`.
 #'
+#' # Tidying
+#'
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
+#' `terms` (the selectors or variables selected), `value` (the loading),
+#' and `component` is returned.
+#'
 #' @references Hyvarinen, A., and Oja, E. (2000). Independent
 #'  component analysis: algorithms and applications. *Neural
 #'  Networks*, 13(4-5), 411-430.
@@ -84,7 +71,7 @@
 #' ica_trans <- step_scale(ica_trans, V1, V2)
 #' ica_trans <- step_ica(ica_trans, V1, V2, num_comp = 2)
 #'
-#' if (require(dimRed) & require(fastICA)) {
+#' if (FALSE) {
 #'   ica_estimates <- prep(ica_trans, training = tr)
 #'   ica_data <- bake(ica_estimates, te)
 #'
@@ -94,9 +81,6 @@
 #'   tidy(ica_trans, number = 3)
 #'   tidy(ica_estimates, number = 3)
 #' }
-#' @seealso [step_pca()] [step_kpca()]
-#'   [step_isomap()] [recipe()] [prep.recipe()]
-#'   [bake.recipe()]
 step_ica <-
   function(recipe,
            ...,
@@ -104,7 +88,9 @@ step_ica <-
            trained = FALSE,
            num_comp  = 5,
            options = list(method = "C"),
+           seed = sample.int(10000, 5),
            res = NULL,
+           columns = NULL,
            prefix = "IC",
            keep_original_cols = FALSE,
            skip = FALSE,
@@ -116,12 +102,14 @@ step_ica <-
     add_step(
       recipe,
       step_ica_new(
-        terms = ellipse_check(...),
+        terms = enquos(...),
         role = role,
         trained = trained,
         num_comp = num_comp,
         options = options,
+        seed = seed,
         res = res,
+        columns = columns,
         prefix = prefix,
         keep_original_cols = keep_original_cols,
         skip = skip,
@@ -131,7 +119,7 @@ step_ica <-
   }
 
 step_ica_new <-
-  function(terms, role, trained, num_comp, options, res,
+  function(terms, role, trained, num_comp, options, seed, res, columns,
            prefix, keep_original_cols, skip, id) {
     step(
       subclass = "ica",
@@ -140,7 +128,9 @@ step_ica_new <-
       trained = trained,
       num_comp = num_comp,
       options = options,
+      seed = seed,
       res = res,
+      columns = columns,
       prefix = prefix,
       keep_original_cols = keep_original_cols,
       skip = skip,
@@ -150,26 +140,30 @@ step_ica_new <-
 
 #' @export
 prep.step_ica <- function(x, training, info = NULL, ...) {
-  col_names <- eval_select_recipes(x$terms, training, info)
+  col_names <- recipes_eval_select(x$terms, training, info)
   check_type(training[, col_names])
 
-  if (x$num_comp > 0) {
+  if (x$num_comp > 0 && length(col_names) > 0) {
     x$num_comp <- min(x$num_comp, length(col_names))
 
-    indc <- dimRed::FastICA(stdpars = x$options)
-    indc <-
-      try(
-        indc@fun(
-          dimRed::dimRedData(as.data.frame(training[, col_names, drop = FALSE])),
-          list(ndim = x$num_comp)
-        ),
-        silent = TRUE
+    cl <-
+      rlang::call2(
+        "fastICA",
+        .ns = "fastICA",
+        n.comp = x$num_comp,
+        X = rlang::expr(as.matrix(training[, col_names]))
       )
+    cl <- rlang::call_modify(cl, !!!x$options)
+    indc <- try(withr::with_seed(x$seed, rlang::eval_tidy(cl)), silent = TRUE)
+
     if (inherits(indc, "try-error")) {
       rlang::abort(paste0("`step_ica` failed with error:\n", as.character(indc)))
+    } else {
+      indc <- indc[c("K", "W")]
+      indc$means <- colMeans(training[, col_names])
     }
   } else {
-    indc <- list(x_vars = col_names)
+    indc <- NULL
   }
 
   step_ica_new(
@@ -178,7 +172,9 @@ prep.step_ica <- function(x, training, info = NULL, ...) {
     trained = TRUE,
     num_comp = x$num_comp,
     options = x$options,
+    seed = x$seed,
     res = indc,
+    columns = col_names,
     prefix = x$prefix,
     keep_original_cols = get_keep_original_cols(x),
     skip = x$skip,
@@ -188,21 +184,19 @@ prep.step_ica <- function(x, training, info = NULL, ...) {
 
 #' @export
 bake.step_ica <- function(object, new_data, ...) {
-  if (object$num_comp > 0) {
-    ica_vars <- colnames(environment(object$res@apply)$indata)
-    comps <-
-      object$res@apply(
-        dimRed::dimRedData(
-          as.data.frame(new_data[, ica_vars, drop = FALSE])
-        )
-      )@data
+  uses_dim_red(object)
+
+  if (object$num_comp > 0 && length(object$columns) > 0) {
+    comps <- scale(as.matrix(new_data[, object$columns]),
+                   center = object$res$means, scale = FALSE)
+    comps <- comps %*% object$res$K %*% object$res$W
     comps <- comps[, 1:object$num_comp, drop = FALSE]
     colnames(comps) <- names0(ncol(comps), object$prefix)
     new_data <- bind_cols(new_data, as_tibble(comps))
     keep_original_cols <- get_keep_original_cols(object)
 
     if (!keep_original_cols) {
-      new_data <- new_data[, !(colnames(new_data) %in% ica_vars), drop = FALSE]
+      new_data <- new_data[, !(colnames(new_data) %in% object$columns), drop = FALSE]
     }
   }
   as_tibble(new_data)
@@ -212,33 +206,39 @@ bake.step_ica <- function(object, new_data, ...) {
 print.step_ica <-
   function(x, width = max(20, options()$width - 29), ...) {
     if (x$num_comp == 0) {
-      cat("No ICA components were extracted.\n")
+      title <- "No ICA components were extracted from "
     } else {
-      cat("ICA extraction with ")
-      printer(colnames(x$res@org.data), x$terms, x$trained, width = width)
+      title <- "ICA extraction with "
     }
 
+    print_step(x$columns, x$terms, x$trained, title, width)
     invisible(x)
   }
 
-#' @rdname step_ica
-#' @param x A `step_ica` object.
+#' @rdname tidy.recipe
 #' @export
 tidy.step_ica <- function(x, ...) {
+  uses_dim_red(x)
   if (is_trained(x)) {
-    if (x$num_comp > 0) {
-      rot <- dimRed::getRotationMatrix(x$res)
-      colnames(rot) <- names0(ncol(rot), x$prefix)
-      rot <- as.data.frame(rot)
-      vars <- colnames(x$res@org.data)
-      npc <- ncol(rot)
-      res <- utils::stack(rot)
-      colnames(res) <- c("value", "component")
-      res$component <- as.character(res$component)
-      res$terms <- rep(vars, npc)
-      res <- as_tibble(res)
+    if (x$num_comp > 0 && length(x$columns) > 0) {
+      res <- x$res$K %*% x$res$W
+      colnames(res) <- names0(ncol(res), x$prefix)
+      res <- as.data.frame(res)
+      res$terms <- x$columns
+      res <-
+        tidyr::pivot_longer(
+          res,
+          cols = dplyr::starts_with(x$prefix),
+          names_to = "component",
+          values_to = "value"
+        )
     } else {
-      res <- tibble(terms = x$res$x_vars, value = na_dbl, component  = na_chr)
+      res <-
+        tibble(
+          terms = unname(x$columns),
+          value = na_dbl,
+          component = na_chr
+        )
     }
   } else {
     term_names <- sel2char(x$terms)
@@ -250,13 +250,13 @@ tidy.step_ica <- function(x, ...) {
     res$component <- as.character(res$component)
     res <- as_tibble(res)
   }
+
   res$id <- x$id
-  res <- arrange(res, terms, component)
-  select(res, terms, component, value, id)
+  res <- dplyr::arrange(res, terms, component)
+
+  dplyr::select(res, terms, component, value, id)
 }
 
-
-#' @rdname tunable.step
 #' @export
 tunable.step_ica <- function(x, ...) {
   tibble::tibble(
@@ -269,8 +269,8 @@ tunable.step_ica <- function(x, ...) {
 }
 
 
-#' @rdname required_pkgs.step
+#' @rdname required_pkgs.recipe
 #' @export
 required_pkgs.step_ica <- function(x, ...) {
-  c("dimRed", "fastICA")
+  c("fastICA")
 }
