@@ -6,7 +6,7 @@
 #'
 #' @inheritParams step_center
 #' @param means A named numeric vector of means. This is `NULL` until computed
-#'  by [prep.recipe()]. Note that, if the original data are integers, the mean
+#'  by [prep()]. Note that, if the original data are integers, the mean
 #'  will be converted to an integer to maintain the same data type.
 #' @param trim The fraction (0 to 0.5) of observations to be trimmed from each
 #'  end of the variables before the mean is computed. Values of trim outside
@@ -18,13 +18,15 @@
 #'  in the `training` argument of `prep.recipe`. `bake.recipe` then applies the
 #'  new values to new data sets using these averages.
 #'
-#' When you [`tidy()`] this step, a tibble with
-#'  columns `terms` (the selectors or variables selected) and `model` (the mean
-#'  value) is returned.
-#'
 #'  As of `recipes` 0.1.16, this function name changed from `step_meanimpute()`
 #'    to `step_impute_mean()`.
 #'
+#' # Tidying
+#'
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
+#' `terms` (the selectors or variables selected) and `model` (the mean
+#' value) is returned.
+#'
 #' @examples
 #' library(modeldata)
 #' data("credit_data")
@@ -66,7 +68,7 @@ step_impute_mean <-
     add_step(
       recipe,
       step_impute_mean_new(
-        terms = ellipse_check(...),
+        terms = enquos(...),
         role = role,
         trained = trained,
         means = means,
@@ -160,8 +162,8 @@ bake.step_meanimpute <- bake.step_impute_mean
 #' @export
 print.step_impute_mean <-
   function(x, width = max(20, options()$width - 30), ...) {
-    cat("Mean Imputation for ", sep = "")
-    printer(names(x$means), x$terms, x$trained, width = width)
+    title <- "Mean imputation for "
+    print_step(names(x$means), x$terms, x$trained, title, width)
     invisible(x)
   }
 
@@ -174,7 +176,7 @@ print.step_meanimpute <- print.step_impute_mean
 tidy.step_impute_mean <- function(x, ...) {
   if (is_trained(x)) {
     res <- tibble(terms = names(x$means),
-                  model = unlist(x$means))
+                  model = vctrs::vec_unchop(unname(x$means), ptype = double()))
   } else {
     term_names <- sel2char(x$terms)
     res <- tibble(terms = term_names, model = na_dbl)
@@ -187,7 +189,6 @@ tidy.step_impute_mean <- function(x, ...) {
 #' @keywords internal
 tidy.step_meanimpute <- tidy.step_impute_mean
 
-#' @rdname tunable.recipe
 #' @export
 tunable.step_impute_mean <- function(x, ...) {
   tibble::tibble(
