@@ -1,26 +1,16 @@
-#' Impute Nominal Data Using the Most Common Value
+#' Impute nominal data using the most common value
 #'
 #'   `step_impute_mode` creates a *specification* of a
 #'  recipe step that will substitute missing values of nominal
 #'  variables by the training set mode of those variables.
 #'
 #' @inheritParams step_center
-#' @param ... One or more selector functions to choose which
-#'  variables are affected by the step. See [selections()]
-#'  for more details. For the `tidy` method, these are not
-#'  currently used.
-#' @param role Not used by this step since no new variables are
-#'  created.
 #' @param modes A named character vector of modes. This is
-#'  `NULL` until computed by [prep.recipe()].
-#' @return An updated version of `recipe` with the new step
-#'  added to the sequence of existing steps (if any). For the
-#'  `tidy` method, a tibble with columns `terms` (the
-#'  selectors or variables selected) and `model` (the mode
-#'  value).
-#' @keywords datagen
-#' @concept preprocessing
-#' @concept imputation
+#'  `NULL` until computed by [prep()].
+#' @param ptype A data frame prototype to cast new data sets to. This is
+#'  commonly a 0-row slice of the training set.
+#' @template step-return
+#' @family imputation steps
 #' @export
 #' @details `step_impute_mode` estimates the variable modes
 #'  from the data used in the `training` argument of
@@ -31,6 +21,12 @@
 #'  As of `recipes` 0.1.16, this function name changed from `step_modeimpute()`
 #'    to `step_impute_mode()`.
 #'
+#' # Tidying
+#'
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
+#' `terms` (the selectors or variables selected) and `model` (the mode
+#' value) is returned.
+#'
 #' @examples
 #' library(modeldata)
 #' data("credit_data")
@@ -65,15 +61,17 @@ step_impute_mode <-
            role = NA,
            trained = FALSE,
            modes = NULL,
+           ptype = NULL,
            skip = FALSE,
            id = rand_id("impute_mode")) {
     add_step(
       recipe,
       step_impute_mode_new(
-        terms = ellipse_check(...),
+        terms = enquos(...),
         role = role,
         trained = trained,
         modes = modes,
+        ptype = ptype,
         skip = skip,
         id = id
       )
@@ -88,9 +86,10 @@ step_modeimpute <-
            role = NA,
            trained = FALSE,
            modes = NULL,
+           ptype = NULL,
            skip = FALSE,
            id = rand_id("impute_mode")) {
-    lifecycle::deprecate_soft(
+    lifecycle::deprecate_warn(
       when = "0.1.16",
       what = "recipes::step_modeimpute()",
       with = "recipes::step_impute_mode()"
@@ -101,19 +100,21 @@ step_modeimpute <-
       role = role,
       trained = trained,
       modes = modes,
+      ptype = ptype,
       skip = skip,
       id = id
     )
   }
 
 step_impute_mode_new <-
-  function(terms, role, trained, modes, skip, id) {
+  function(terms, role, trained, modes, ptype, skip, id) {
     step(
       subclass = "impute_mode",
       terms = terms,
       role = role,
       trained = trained,
       modes = modes,
+      ptype = ptype,
       skip = skip,
       id = id
     )
@@ -121,25 +122,39 @@ step_impute_mode_new <-
 
 #' @export
 prep.step_impute_mode <- function(x, training, info = NULL, ...) {
-  col_names <- eval_select_recipes(x$terms, training, info)
+  col_names <- recipes_eval_select(x$terms, training, info)
   modes <- vapply(training[, col_names], mode_est, c(mode = ""))
+  ptype <- vec_slice(training[, col_names], 0)
   step_impute_mode_new(
     terms = x$terms,
     role = x$role,
     trained = TRUE,
     modes = modes,
+    ptype = ptype,
     skip = x$skip,
     id = x$id
   )
 }
 
 #' @export
+#' @keywords internal
 prep.step_modeimpute <- prep.step_impute_mode
 
 #' @export
 bake.step_impute_mode <- function(object, new_data, ...) {
+
   for (i in names(object$modes)) {
     if (any(is.na(new_data[, i]))) {
+      if(is.null(object$ptype)) {
+        rlang::warn(
+          paste0(
+            "'ptype' was added to `step_impute_mode()` after this recipe was created.\n",
+            "Regenerate your recipe to avoid this warning."
+          )
+        )
+      } else {
+        new_data[[i]] <- vec_cast(new_data[[i]], object$ptype[[i]])
+      }
       mode_val <- cast(object$modes[[i]], new_data[[i]])
       new_data[is.na(new_data[[i]]), i] <- mode_val
     }
@@ -148,17 +163,19 @@ bake.step_impute_mode <- function(object, new_data, ...) {
 }
 
 #' @export
+#' @keywords internal
 bake.step_modeimpute <- bake.step_impute_mode
 
 #' @export
 print.step_impute_mode <-
   function(x, width = max(20, options()$width - 30), ...) {
-    cat("Mode Imputation for ", sep = "")
-    printer(names(x$modes), x$terms, x$trained, width = width)
+    title <- "Mode imputation for "
+    print_step(names(x$modes), x$terms, x$trained, title, width)
     invisible(x)
   }
 
 #' @export
+#' @keywords internal
 print.step_modeimpute <- print.step_impute_mode
 
 mode_est <- function(x) {
@@ -169,13 +186,12 @@ mode_est <- function(x) {
   sample(modes, size = 1)
 }
 
-#' @rdname step_impute_mode
-#' @param x A `step_impute_mode` object.
+#' @rdname tidy.recipe
 #' @export
 tidy.step_impute_mode <- function(x, ...) {
   if (is_trained(x)) {
     res <- tibble(terms = names(x$modes),
-                  model = x$modes)
+                  model = unname(x$modes))
   } else {
     term_names <- sel2char(x$terms)
     res <- tibble(terms = term_names, model = na_chr)
@@ -185,4 +201,5 @@ tidy.step_impute_mode <- function(x, ...) {
 }
 
 #' @export
+#' @keywords internal
 tidy.step_modeimpute <- tidy.step_impute_mode
