@@ -4,30 +4,18 @@
 #'  step that will create new columns that are interaction terms
 #'  between two or more variables.
 #'
+#' @inheritParams step_pca
 #' @inheritParams step_center
-#' @param ... One or more selector functions to choose which
-#'  variables are affected by the step. See [selections()]
-#'  for more details, and consider using [tidyselect::starts_with()] when
-#'  dummy variables have been created. For the `tidy` method, these are not
-#'  currently used.
 #' @param terms A traditional R formula that contains interaction
-#'  terms. This can include `.` and selectors.
-#' @param role For model terms created by this step, what analysis
-#'  role should they be assigned?. By default, the function assumes
-#'  that the new columns created from the original variables will be
-#'  used as predictors in a model.
+#'  terms. This can include `.` and selectors. See [selections()]
+#'  for more details, and consider using [tidyselect::starts_with()] when
+#'  dummy variables have been created.
 #' @param objects A list of `terms` objects for each
 #'  individual interaction.
 #' @param sep A character value used to delineate variables in an
 #'  interaction (e.g. `var1_x_var2` instead of the more
 #'  traditional `var1:var2`).
-#' @return An updated version of `recipe` with the new step
-#'  added to the sequence of existing steps (if any). For the
-#'  `tidy` method, a tibble with columns `terms` which is
-#'  the interaction effects.
-#' @keywords datagen
-#' @concept preprocessing
-#' @concept model_specification
+#' @template step-return
 #' @export
 #' @details `step_interact` can create interactions between
 #'  variables. It is primarily intended for **numeric data**;
@@ -60,7 +48,11 @@
 #'  `starts_with("x_")` resolves to `(x_2 + x_3 + x_4 + x_5 + x_6)`
 #'  so that the formula is now `(x_2 + x_3 + x_4 + x_5 + x_6):z` and
 #'  all two-way interactions are created.
-
+#'
+#' # Tidying
+#'
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble with column
+#' `terms` (the interaction effects) is returned.
 #' @examples
 #' library(modeldata)
 #' data(penguins)
@@ -139,17 +131,17 @@ prep.step_interact <- function(x, training, info = NULL, ...) {
   # Use formula environment as quosure env
   env <- rlang::f_env(x$terms)
 
-  eval_select_recipes_expr <- function(expr) {
-    # Wrap `expr` into a list-of-quos as `eval_select_recipes()` expects
+  recipes_eval_select_expr <- function(expr) {
+    # Wrap `expr` into a list-of-quos as `recipes_eval_select()` expects
     quo <- new_quosure(expr, env)
     quos <- list(quo)
-    eval_select_recipes(quos, data = training, info = info)
+    recipes_eval_select(quos, data = training, info = info)
   }
 
   ## Resolve the selectors to a expression containing an additive
   ## function of the variables
   if(length(form_sel) > 0) {
-    form_res <- map(form_sel, eval_select_recipes_expr)
+    form_res <- map(form_sel, recipes_eval_select_expr)
     form_res <- map(form_res, vec_2_expr)
     ## Subsitute the column names into the original interaction
     ## formula.
@@ -298,12 +290,10 @@ make_small_terms <- function(forms, dat) {
 
 print.step_interact <-
   function(x, width = max(20, options()$width - 27), ...) {
-    cat("Interactions with ", sep = "")
-    cat(as.character(x$terms)[-1])
-    if (x$trained)
-      cat(" [trained]\n")
-    else
-      cat("\n")
+    title <- "Interactions with "
+    terms <- as.character(x$terms)[-1]
+    untrained_terms <- rlang::parse_quos(terms, rlang::current_env())
+    print_step(terms, untrained_terms, x$trained, title, width)
     invisible(x)
   }
 
@@ -317,8 +307,7 @@ int_name <- function(x) {
 }
 
 
-#' @rdname step_interact
-#' @param x A `step_interact` object
+#' @rdname tidy.recipe
 #' @export
 tidy.step_interact <- function(x, ...) {
   res <- tibble(terms = vapply(x$objects, int_name, character(1)))
@@ -337,6 +326,8 @@ find_selectors <- function (f) {
   }
   else if (is.call(f)) {
     fname <- as.character(f[[1]])
+    fname <- fname[!(fname %in% c("::", "tidyselect", "dplyr", "recipes"))]
+
     res <- if (fname %in% intersect_selectors) f else list()
     c(res, unlist(lapply(f[-1], find_selectors), use.names = FALSE))
   }
