@@ -7,22 +7,15 @@
 #'   unintentional transformations when calling steps with
 #'   `all_predictors`.
 #'
+#' @inheritParams step_pca
 #' @inheritParams step_center
-#' @param recipe A recipe object. The step will be added to the sequence of
-#'   operations for this recipe.
 #' @param ... Argument ignored; included for consistency with other step
 #'   specification functions.
-#' @param role For model terms created by this step, what analysis
-#'  role should they be assigned?. By default, the function assumes
-#'  that the new columns created from the original variables will be
-#'  used as predictors in a model.
 #' @param trained A logical to indicate if the quantities for preprocessing
-#'   have been estimated. Again included for consistency.
+#'   have been estimated. Again included only for consistency.
 #' @param name Character name for newly added column
 #' @param value A numeric constant to fill the intercept column. Defaults to 1.
-#'
-#' @return An updated version of `recipe` with the
-#'   new step added to the sequence of existing steps (if any).
+#' @template step-return
 #' @export
 #'
 #' @examples
@@ -43,7 +36,6 @@
 #' with_intercept <- bake(rec_obj, biomass_te)
 #' with_intercept
 #'
-#' @seealso [recipe()] [prep.recipe()] [bake.recipe()]
 step_intercept <- function(recipe, ..., role = "predictor",
                            trained = FALSE, name = "intercept",
                            value = 1,
@@ -93,6 +85,8 @@ bake.step_intercept <- function(object, new_data, ...) {
 
 print.step_intercept <-
   function(x, width = max(20, options()$width - 30), ...) {
-    cat("Adding intercept\n")
+    title <- "Adding intercept named: "
+    untrained_terms <- rlang::parse_quos(x$name, rlang::current_env())
+    print_step(x$name, untrained_terms, x$trained, title, width)
     invisible(x)
   }
