@@ -5,26 +5,21 @@
 #'  zero and one.
 #'
 #' @inheritParams step_center
-#' @param ... One or more selector functions to choose which
-#'  variables are affected by the step. See [selections()]
-#'  for more details. For the `tidy` method, these are not
-#'  currently used.
-#' @param role Not used by this step since no new variables are
-#'  created.
 #' @param columns A character string of variable names that will
 #'  be populated (eventually) by the `terms` argument.
-#' @return An updated version of `recipe` with the new step
-#'  added to the sequence of existing steps (if any). For the
-#'  `tidy` method, a tibble with columns `terms` which
-#'  is the columns that will be affected.
-#' @keywords datagen
-#' @concept preprocessing
-#' @concept transformation_methods
+#' @template step-return
+#' @family individual transformation steps
 #' @export
 #' @details The inverse logit transformation takes values on the
 #'  real line and translates them to be between zero and one using
 #'  the function `f(x) = 1/(1+exp(-x))`.
+#'
+#'  # Tidying
+#'
+#'  When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
+#'  `terms` (the columns that will be affected) is returned.
 #' @examples
+#' library(modeldata)
 #' data(biomass)
 #'
 #' biomass_tr <- biomass[biomass$dataset == "Training",]
@@ -42,17 +37,12 @@
 #'
 #' transformed_te <- bake(ilogit_obj, biomass_te)
 #' plot(biomass_te$carbon, transformed_te$carbon)
-#' @seealso [step_logit()] [step_log()]
-#'   [step_sqrt()]  [step_hyperbolic()]
-#'   [recipe()] [prep.recipe()]
-#'   [bake.recipe()]
-
 step_invlogit <-
   function(recipe, ...,  role = NA, trained = FALSE, columns = NULL,
            skip = FALSE, id = rand_id("invlogit")) {
     add_step(recipe,
              step_invlogit_new(
-               terms = ellipse_check(...),
+               terms = enquos(...),
                role = role,
                trained = trained,
                columns = columns,
@@ -76,7 +66,7 @@ step_invlogit_new <-
 
 #' @export
 prep.step_invlogit <- function(x, training, info = NULL, ...) {
-  col_names <- terms_select(x$terms, info = info)
+  col_names <- recipes_eval_select(x$terms, training, info)
   check_type(training[, col_names])
 
   step_invlogit_new(
@@ -101,13 +91,12 @@ bake.step_invlogit <- function(object, new_data, ...) {
 
 print.step_invlogit <-
   function(x, width = max(20, options()$width - 26), ...) {
-    cat("Inverse logit on ", sep = "")
-    printer(x$columns, x$terms, x$trained, width = width)
+    title <- "Inverse logit on "
+    print_step(x$columns, x$terms, x$trained, title, width)
     invisible(x)
   }
 
-#' @rdname step_invlogit
-#' @param x A `step_invlogit` object.
+#' @rdname tidy.recipe
 #' @export
 tidy.step_invlogit <- function(x, ...) {
   res <- simple_terms(x, ...)
