@@ -15,7 +15,8 @@ get_types <- function(x) {
       logical = "logical",
       Date = "date",
       POSIXct = "date",
-      list = "list"
+      list = "list",
+      textrecipes_tokenlist = "tokenlist"
     )
 
   classes <- lapply(x, class)
@@ -62,7 +63,7 @@ get_rhs_vars <- function(formula, data, no_lhs = FALSE) {
   ## or should it? what about Y ~ log(x)?
   ## Answer: when called from `form2args`, the function
   ## `inline_check` stops when in-line functions are used.
-  data_info <- attr(model.frame(formula, data), "terms")
+  data_info <- attr(model.frame(formula, data[1,]), "terms")
   response_info <- attr(data_info, "response")
   predictor_names <- names(attr(data_info, "dataClasses"))
   if (length(response_info) > 0 && all(response_info > 0)) {
@@ -123,26 +124,33 @@ mod_call_args <- function(cl, args, removals = NULL) {
 #' @param ordinal A logical; was the original factor ordered?
 #' @param sep A single character value for the separator between the names and
 #'  levels.
+#'
+#' @details When using `dummy_names()`, factor levels that are not valid
+#'  variable names (e.g. "some text  with spaces") will be changed to valid
+#'  names by [base::make.names()]; see example below. This function will also
+#'  change the names of ordinal dummy variables. Instead of values such as
+#'  "`.L`", "`.Q`", or "`^4`", ordinal dummy variables are given simple integer
+#'  suffixes such as "`_1`", "`_2`", etc.
+#'
 #' @return `names0` returns a character string of length `num` and
 #'  `dummy_names` generates a character vector the same length as
 #'  `lvl`.
-#' @keywords datagen
-#' @concept string_functions
-#' @concept naming_functions
 #' @examples
-#' names0(9, "x")
-#' names0(10, "x")
+#' names0(9, "a")
+#' names0(10, "a")
 #'
-#' example <- data.frame(y = ordered(letters[1:5]),
-#'                       z = factor(LETTERS[1:5]))
+#' example <- data.frame(x = ordered(letters[1:5]),
+#'                       y = factor(LETTERS[1:5]),
+#'                       z = factor(paste(LETTERS[1:5], 1:5)))
 #'
+#' dummy_names("y", levels(example$y)[-1])
 #' dummy_names("z", levels(example$z)[-1])
 #'
-#' after_mm <- colnames(model.matrix(~y, data = example))[-1]
+#' after_mm <- colnames(model.matrix(~x, data = example))[-1]
 #' after_mm
-#' levels(example$y)
+#' levels(example$x)
 #'
-#' dummy_names("y", substring(after_mm, 2), ordinal = TRUE)
+#' dummy_names("x", substring(after_mm, 2), ordinal = TRUE)
 #' @export
 
 names0 <- function(num, prefix = "x") {
@@ -156,6 +164,11 @@ names0 <- function(num, prefix = "x") {
 #' @export
 #' @rdname names0
 dummy_names <- function(var, lvl, ordinal = FALSE, sep = "_") {
+  # Work around `paste()` recycling bug with 0 length input
+  args <- vctrs::vec_recycle_common(var, lvl)
+  var <- args[[1]]
+  lvl <- args[[2]]
+
   if(!ordinal)
     nms <- paste(var, make.names(lvl), sep = sep)
   else
@@ -165,6 +178,33 @@ dummy_names <- function(var, lvl, ordinal = FALSE, sep = "_") {
   nms
 }
 
+#' @export
+#' @rdname names0
+dummy_extract_names <- function(var, lvl, ordinal = FALSE, sep = "_") {
+  # Work around `paste()` recycling bug with 0 length input
+  args <- vctrs::vec_recycle_common(var, lvl)
+  var <- args[[1]]
+  lvl <- args[[2]]
+
+  if(!ordinal)
+    nms <- paste(var, make.names(lvl), sep = sep)
+  else
+    # assuming they are in order:
+    nms <- paste0(var, names0(length(lvl), sep))
+
+  while (any(duplicated(nms))) {
+    dupe_count <- vapply(seq_along(nms), function(i) {
+      sum(nms[i] == nms[1:i])
+    }, 1L)
+    nms[dupe_count > 1] <- paste(
+      nms[dupe_count > 1],
+      dupe_count[dupe_count > 1],
+      sep = sep
+    )
+  }
+  nms
+}
+
 
 ## As suggested by HW, brought in from the `pryr` package
 ## https://github.com/hadley/pryr
@@ -279,6 +319,9 @@ merge_term_info <- function(.new, .old) {
 
 #' Check for Empty Ellipses
 #'
+#' `ellipse_check()` is deprecated. Instead, empty selections should be
+#' supported by all steps.
+#'
 #' @param ... Arguments pass in from a call to `step`
 #' @return If not empty, a list of quosures. If empty, an error is thrown.
 #' @export
@@ -317,15 +360,22 @@ printer <- function(tr_obj = NULL,
                     width = max(20, options()$width - 30)) {
   if (trained) {
     txt <- format_ch_vec(tr_obj, width = width)
-  } else
+  } else {
     txt <- format_selectors(untr_obj, width = width)
-  if (nchar(txt) == 0)
+  }
+
+  if (length(txt) == 0L) {
     txt <- "<none>"
+  }
+
   cat(txt)
-  if (trained)
+
+  if (trained) {
     cat(" [trained]\n")
-  else
+  } else {
     cat("\n")
+  }
+
   invisible(NULL)
 }
 
@@ -379,11 +429,8 @@ fully_trained <- function(x) {
 #' rec <- recipe(Species ~ ., data = iris) %>%
 #'   step_intercept()
 #'
-#' detect_step(rec, "step_intercept")
+#' detect_step(rec, "intercept")
 detect_step <- function(recipe, name) {
-  exports <- getNamespaceExports("recipes")
-  if (!any(grepl(paste0(".*", name, ".*"), exports)))
-    rlang::abort("Please provide the name of valid step or check (ex: `center`).")
   name %in% tidy(recipe)$type
 }
 
@@ -692,12 +739,6 @@ is_tune <- function(x) {
   FALSE
 }
 
-# ------------------------------------------------------------------------------
-
-tidyr_new_interface <- function() {
-  utils::packageVersion("tidyr") > "0.8.99"
-}
-
 # ------------------------------------------------------------------------------
 # For all imputation functions that substitute elements into an existing vector:
 # vctrs's cast functions would be better but we'll deal with the known cases
@@ -714,13 +755,6 @@ cast <- function(x, ref) {
   x
 }
 
-## -----------------------------------------------------------------------------
-
-tidyselect_pre_1.0.0 <- function() {
-  utils::packageVersion("tidyselect") <= "0.2.5"
-}
-
-
 ## -----------------------------------------------------------------------------
 
 print_col_names <- function(x, prefix = "") {
@@ -760,3 +794,27 @@ changelog <- function(show, before, after, x) {
   }
 }
 
+# ------------------------------------------------------------------------------
+
+eval_dimred_call <- function(fn, ...) {
+  cl <- rlang::call2(fn, .ns = "dimRed", ...)
+  rlang::eval_tidy(cl)
+}
+
+dimred_data <- function(dat) {
+  cl <- rlang::call2("dimRedData", .ns = "dimRed", rlang::expr(as.matrix(dat)))
+  rlang::eval_tidy(cl)
+}
+
+uses_dim_red <- function(x) {
+  dr <- inherits(x, "dimRedResult")
+  if (dr) {
+    rlang::abort(
+      paste(
+        "Recipes version >= 0.1.17 represents the estimates using a different format.",
+        "Please recreate this recipe or use version 0.1.16 or less. See issue #823."
+      )
+    )
+  }
+  invisible(NULL)
+}
