@@ -8,10 +8,16 @@
 #' @param fn A function fun, a quosure style lambda `~ fun(.)`` or a list of
 #' either form. (see [dplyr::mutate_at()]). **Note that this argument must be
 #' named**.
-#' @param inputs A vector of column names populated by `prep()`.
+#' @param inputs A vector of column names populated by [prep()].
 #' @template step-return
-#' @details When you [`tidy()`] this step, a tibble with
-#'  column `terms` which contains the columns being transformed is returned.
+#' @template mutate-leakage
+#' @details
+#'
+#' # Tidying
+#'
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble with column
+#' `terms` which contains the columns being transformed is returned.
+#'
 #' @family multivariate transformation steps
 #' @family dplyr steps
 #' @export
@@ -43,7 +49,7 @@ step_mutate_at <- function(
   add_step(
     recipe,
     step_mutate_at_new(
-      terms = ellipse_check(...),
+      terms = enquos(...),
       fn = fn,
       trained = trained,
       role = role,
@@ -91,8 +97,8 @@ bake.step_mutate_at <- function(object, new_data, ...) {
 
 print.step_mutate_at <-
   function(x, width = max(20, options()$width - 35), ...) {
-    cat("Variable mutation for ", sep = "")
-    printer(x$inputs, x$terms, x$trained, width = width)
+    title <- "Variable mutation for "
+    print_step(x$inputs, x$terms, x$trained, title, width)
     invisible(x)
   }
 
@@ -100,7 +106,7 @@ print.step_mutate_at <-
 #' @export
 tidy.step_mutate_at <- function(x, ...) {
   if (is_trained(x)) {
-    res <- tibble(terms = x$inputs)
+    res <- tibble(terms = unname(x$inputs))
   } else {
     term_names <- sel2char(x$terms)
     res <- tibble(terms = term_names)
