@@ -1,23 +1,17 @@
-#' NNMF Signal Extraction
+#' Non-Negative Matrix Factorization Signal Extraction
+#'
+#' @description
 #'
 #' `step_nnmf` creates a *specification* of a recipe step
 #'  that will convert numeric data into one or more non-negative
 #'  components.
 #'
+#' `r lifecycle::badge("soft-deprecated")`
+#'
+#' Please use [step_nnmf_sparse()] instead of this step function.
+#'
+#' @inheritParams step_pca
 #' @inheritParams step_center
-#' @inherit step_center return
-#' @param ... One or more selector functions to choose which
-#'  variables will be used to compute the components. See
-#'  [selections()] for more details. For the `tidy`
-#'  method, these are not currently used.
-#' @param role For model terms created by this step, what analysis
-#'  role should they be assigned?. By default, the function assumes
-#'  that the new component columns created by the
-#'  original variables will be used as predictors in a model.
-#' @param num_comp The number of components to retain as new
-#'  predictors. If `num_comp` is greater than the number of columns
-#'  or the number of possible components, a smaller value will be
-#'  used.
 #' @param num_run A positive integer for the number of computations runs used
 #'  to obtain a consensus projection.
 #' @param options A list of options to `nmf()` in the NMF package by way of the
@@ -26,21 +20,15 @@
 #'  processing is turned off in favor of resample-level parallelization.
 #' @param res The `NNMF()` object is stored
 #'  here once this preprocessing step has been trained by
-#'  [prep.recipe()].
+#'  [prep()].
+#' @param columns A character string of variable names that will
+#'  be populated elsewhere.
 #' @param prefix A character string that will be the prefix to the
 #'  resulting new variables. See notes below.
 #' @param seed An integer that will be used to set the seed in isolation
 #'  when computing the factorization.
-#' @param keep_original_cols A logical to keep the original variables in the
-#'  output. Defaults to `FALSE`.
-#' @return An updated version of `recipe` with the new step
-#'  added to the sequence of existing steps (if any). For the
-#'  `tidy` method, a tibble with columns `terms` (the
-#'  selectors or variables selected) and the number of components.
-#' @keywords datagen
-#' @concept preprocessing
-#' @concept nnmf
-#' @concept projection_methods
+#' @template step-return
+#' @family multivariate transformation steps
 #' @export
 #' @details Non-negative matrix factorization computes latent components that
 #'  have non-negative values and take into account that the original data
@@ -55,6 +43,13 @@
 #'  If `num = 101`, the names would be `NNMF001` -
 #'  `NNMF101`.
 #'
+#'
+#' # Tidying
+#'
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble with column
+#' `terms` (the selectors or variables selected) and the number of
+#' components is returned.
+#'
 #' @examples
 #'
 #' library(modeldata)
@@ -71,10 +66,6 @@
 #' # library(ggplot2)
 #' # bake(rec, new_data = NULL) %>%
 #' #  ggplot(aes(x = NNMF2, y = NNMF1, col = HHV)) + geom_point()
-#'
-#' @seealso [step_pca()], [step_ica()], [step_kpca()],
-#'   [step_isomap()], [recipe()], [prep.recipe()],
-#'   [bake.recipe()]
 step_nnmf <-
   function(recipe,
            ...,
@@ -84,6 +75,7 @@ step_nnmf <-
            num_run = 30,
            options = list(),
            res = NULL,
+           columns = NULL,
            prefix = "NNMF",
            seed = sample.int(10^5, 1),
            keep_original_cols = FALSE,
@@ -91,16 +83,18 @@ step_nnmf <-
            id = rand_id("nnmf")
            ) {
     recipes_pkg_check(required_pkgs.step_nnmf())
+    lifecycle::deprecate_soft("0.2.0", "step_nnmf()", "step_nnmf_sparse()")
     add_step(
       recipe,
       step_nnmf_new(
-        terms = ellipse_check(...),
+        terms = enquos(...),
         role = role,
         trained = trained,
         num_comp = num_comp,
         num_run = num_run,
         options = options,
         res = res,
+        columns = columns,
         prefix = prefix,
         seed = seed,
         keep_original_cols = keep_original_cols,
@@ -111,7 +105,7 @@ step_nnmf <-
   }
 
 step_nnmf_new <-
-  function(terms, role, trained, num_comp, num_run, options, res,
+  function(terms, role, trained, num_comp, num_run, options, res, columns,
            prefix, seed, keep_original_cols, skip, id) {
     step(
       subclass = "nnmf",
@@ -122,6 +116,7 @@ step_nnmf_new <-
       num_run = num_run,
       options = options,
       res = res,
+      columns = columns,
       prefix = prefix,
       seed = seed,
       keep_original_cols = keep_original_cols,
@@ -132,30 +127,35 @@ step_nnmf_new <-
 
 #' @export
 prep.step_nnmf <- function(x, training, info = NULL, ...) {
-  col_names <- eval_select_recipes(x$terms, training, info)
+  col_names <- recipes_eval_select(x$terms, training, info)
 
   check_type(training[, col_names])
 
-  if (x$num_comp > 0) {
+  if (x$num_comp > 0 && length(col_names) > 0) {
 
     x$num_comp <- min(x$num_comp, length(col_names))
 
-    opts <- list(options = x$options)
-    opts$ndim <- x$num_comp
-    opts$nrun <- x$num_run
-    opts$seed <- x$seed
-    opts$.mute <- c("message", "output")
-    opts$.data <- dimRed::dimRedData(as.data.frame(training[, col_names, drop = FALSE]))
-    opts$.method <- "NNMF"
     nmf_opts <- list(parallel = FALSE, parallel.required = FALSE)
-    opts$options <- list(.options = nmf_opts)
 
-    nnm <- try(do.call(dimRed::embed, opts), silent = TRUE)
+    nnm <- try(
+      eval_dimred_call(
+        "embed",
+        .method = "NNMF",
+        .data = dimred_data(training[, col_names, drop = FALSE]),
+        ndim = x$num_comp,
+        nrun = x$num_run,
+        seed = x$seed,
+        .mute = c("message", "output"),
+        options = x$options,
+        .options = nmf_opts
+      ),
+      silent = TRUE
+    )
     if (inherits(nnm, "try-error")) {
       rlang::abort(paste0("`step_nnmf` failed with error:\n", as.character(nnm)))
     }
   } else {
-    nnm <- list(x_vars = col_names)
+    nnm <- NULL
   }
 
   step_nnmf_new(
@@ -166,6 +166,7 @@ prep.step_nnmf <- function(x, training, info = NULL, ...) {
     num_run = x$num_run,
     options = x$options,
     res = nnm,
+    columns = col_names,
     prefix = x$prefix,
     seed = x$seed,
     keep_original_cols = get_keep_original_cols(x),
@@ -176,14 +177,10 @@ prep.step_nnmf <- function(x, training, info = NULL, ...) {
 
 #' @export
 bake.step_nnmf <- function(object, new_data, ...) {
-  if (object$num_comp > 0) {
+  if (object$num_comp > 0 && length(object$columns) > 0) {
     nnmf_vars <- rownames(object$res@other.data$w)
     comps <-
-      object$res@apply(
-        dimRed::dimRedData(
-          as.data.frame(new_data[, nnmf_vars, drop = FALSE])
-        )
-      )@data
+      object$res@apply(dimred_data(new_data[, nnmf_vars, drop = FALSE]))@data
     comps <- comps[, 1:object$num_comp, drop = FALSE]
     colnames(comps) <- names0(ncol(comps), object$prefix)
     new_data <- bind_cols(new_data, as_tibble(comps))
@@ -198,21 +195,17 @@ bake.step_nnmf <- function(object, new_data, ...) {
 
 
 print.step_nnmf <- function(x, width = max(20, options()$width - 29), ...) {
-  if (x$num_comp == 0) {
-    cat("Non-negative matrix factorization was not done.\n")
-  } else {
-    cat("Non-negative matrix factorization for ")
-    printer(colnames(x$res@org.data), x$terms, x$trained, width = width)
-  }
+  title <- "Non-negative matrix factorization for "
+  print_step(colnames(x$res@org.data), x$terms, x$trained, title, width)
   invisible(x)
 }
 
 
-#' @rdname step_nnmf
-#' @param x A `step_nnmf` object.
+#' @rdname tidy.recipe
+#' @export
 tidy.step_nnmf <- function(x, ...) {
   if (is_trained(x)) {
-    if (x$num_comp > 0) {
+    if (x$num_comp > 0 && length(x$columns) > 0) {
       res <- x$res@other.data$w
       var_nms <- rownames(res)
       res <- tibble::as_tibble(res)
@@ -222,7 +215,7 @@ tidy.step_nnmf <- function(x, ...) {
       res <- res[,c("terms", "value", "component")]
       res <- res[order(res$component, res$terms),]
     } else {
-      res <- tibble(terms = x$res$x_vars, value = na_dbl, component  = na_chr)
+      res <- tibble(terms = unname(x$columns), value = na_dbl, component  = na_dbl)
     }
   } else {
     term_names <- sel2char(x$terms)
@@ -234,7 +227,6 @@ tidy.step_nnmf <- function(x, ...) {
 
 # ------------------------------------------------------------------------------
 
-#' @rdname tunable.step
 #' @export
 tunable.step_nnmf <- function(x, ...) {
   tibble::tibble(
@@ -249,7 +241,7 @@ tunable.step_nnmf <- function(x, ...) {
   )
 }
 
-#' @rdname required_pkgs.step
+#' @rdname required_pkgs.recipe
 #' @export
 required_pkgs.step_nnmf <- function(x, ...) {
   c("dimRed", "NMF")
