@@ -5,33 +5,29 @@
 #'  deviation of one and a mean of zero.
 #'
 #' @inheritParams step_center
-#' @param ... One or more selector functions to choose which
-#'  variables are affected by the step. See [selections()]
-#'  for more details. For the `tidy` method, these are not
-#'  currently used.
-#' @param role Not used by this step since no new variables are
-#'  created.
 #' @param means A named numeric vector of means. This is
-#'  `NULL` until computed by [prep.recipe()].
+#'  `NULL` until computed by [prep()].
 #' @param sds A named numeric vector of standard deviations This
-#'  is `NULL` until computed by [prep.recipe()].
+#'  is `NULL` until computed by [prep()].
 #' @param na_rm A logical value indicating whether `NA`
 #'  values should be removed when computing the standard deviation and mean.
-#' @return An updated version of `recipe` with the new step
-#'  added to the sequence of existing steps (if any). For the
-#'  `tidy` method, a tibble with columns `terms` (the
-#'  selectors or variables selected), `value` (the
-#'  standard deviations and means), and `statistic` for the type of value.
-#' @keywords datagen
-#' @concept preprocessing
-#' @concept normalization_methods
+#' @template step-return
+#' @family normalization steps
 #' @export
 #' @details Centering data means that the average of a variable is subtracted
 #'  from the data. Scaling data means that the standard deviation of a variable
 #'  is divided out of the data. `step_normalize` estimates the variable standard
 #'  deviations and means from the data used in the `training` argument of
-#'  `prep.recipe`. `bake.recipe` then applies the scaling to new data sets using
+#'  `prep.recipe`. [`bake.recipe`] then applies the scaling to new data sets using
 #'  these estimates.
+#'
+#'  # Tidying
+#'
+#'  When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
+#'  `terms` (the selectors or variables selected), `value` (the standard
+#'  deviations and means), and `statistic` for the type of value is
+#'  returned.
+#'
 #' @examples
 #' library(modeldata)
 #' data(biomass)
@@ -76,7 +72,7 @@ step_normalize <-
     add_step(
       recipe,
       step_normalize_new(
-        terms = ellipse_check(...),
+        terms = enquos(...),
         role = role,
         trained = trained,
         means = means,
@@ -105,7 +101,7 @@ step_normalize_new <-
 
 #' @export
 prep.step_normalize <- function(x, training, info = NULL, ...) {
-  col_names <- eval_select_recipes(x$terms, training, info)
+  col_names <- recipes_eval_select(x$terms, training, info)
 
   check_type(training[, col_names])
 
@@ -134,20 +130,19 @@ bake.step_normalize <- function(object, new_data, ...) {
 
 print.step_normalize <-
   function(x, width = max(20, options()$width - 30), ...) {
-    cat("Centering and scaling for ", sep = "")
-    printer(names(x$sds), x$terms, x$trained, width = width)
+    title <- "Centering and scaling for "
+    print_step(names(x$sds), x$terms, x$trained, title, width)
     invisible(x)
   }
 
 
-#' @rdname step_normalize
-#' @param x A `step_normalize` object.
+#' @rdname tidy.recipe
 #' @export
 tidy.step_normalize <- function(x, ...) {
   if (is_trained(x)) {
     res <- tibble(terms = c(names(x$means), names(x$sds)),
                   statistic = rep(c("mean", "sd"), each = length(x$sds)),
-                  value = c(x$means, x$sds))
+                  value = unname(c(x$means, x$sds)))
   } else {
     term_names <- sel2char(x$terms)
     res <- tibble(terms = term_names,
