@@ -4,15 +4,8 @@
 #'  that will create new columns that are basis expansions of
 #'  variables using natural splines.
 #'
+#' @inheritParams step_pca
 #' @inheritParams step_center
-#' @param ... One or more selector functions to choose which
-#'  variables are affected by the step. See [selections()]
-#'  for more details. For the `tidy` method, these are not
-#'  currently used.
-#' @param role For model terms created by this step, what analysis
-#'  role should they be assigned?. By default, the function assumes
-#'  that the new columns created from the original variables will be
-#'  used as predictors in a model.
 #' @param deg_free The degrees of freedom for the natural spline. As the
 #'  degrees of freedom for a natural spline increase, more flexible and
 #'  complex curves can be generated. When a single degree of freedom is used,
@@ -21,13 +14,8 @@
 #'  created once the step has been trained.
 #' @param options A list of options for [splines::ns()]
 #'  which should not include `x` or `df`.
-#' @return An updated version of `recipe` with the new step
-#'  added to the sequence of existing steps (if any). For the
-#'  `tidy` method, a tibble with columns `terms` which is
-#'  the columns that will be affected and `holiday`.
-#' @keywords datagen
-#' @concept preprocessing
-#' @concept basis_expansion
+#' @template step-return
+#' @family individual transformation steps
 #' @export
 #' @details `step_ns` can create new features from a single variable
 #'  that enable fitting routines to model this variable in a
@@ -36,6 +24,12 @@
 #'  [splines::ns()]. The original variables are removed
 #'  from the data and new columns are added. The naming convention
 #'  for the new variables is `varname_ns_1` and so on.
+#'
+#'  # Tidying
+#'
+#'  When you [`tidy()`][tidy.recipe()] this step, a tibble with column
+#'  `terms` (the columns that will be affected) is returned.
+#'
 #' @examples
 #' library(modeldata)
 #' data(biomass)
@@ -52,9 +46,6 @@
 #'
 #' expanded <- bake(with_splines, biomass_te)
 #' expanded
-#' @seealso [step_poly()] [recipe()]
-#'   [prep.recipe()] [bake.recipe()]
-
 step_ns <-
   function(recipe,
            ...,
@@ -68,7 +59,7 @@ step_ns <-
     add_step(
       recipe,
       step_ns_new(
-        terms = ellipse_check(...),
+        terms = enquos(...),
         trained = trained,
         deg_free = deg_free,
         role = role,
@@ -132,7 +123,7 @@ ns_predict <- function(object, x) {
 
 #' @export
 prep.step_ns <- function(x, training, info = NULL, ...) {
-  col_names <- eval_select_recipes(x$terms, training, info)
+  col_names <- recipes_eval_select(x$terms, training, info)
 
   check_type(training[, col_names])
 
@@ -181,28 +172,22 @@ bake.step_ns <- function(object, new_data, ...) {
 
 print.step_ns <-
   function(x, width = max(20, options()$width - 28), ...) {
-    cat("Natural Splines on ")
-    printer(names(x$objects), x$terms, x$trained, width = width)
+    title <- "Natural splines on "
+    print_step(names(x$objects), x$terms, x$trained, title, width)
     invisible(x)
   }
 
-#' @rdname step_ns
-#' @param x A `step_ns` object.
+#' @rdname tidy.recipe
 #' @export
 tidy.step_ns <- function(x, ...) {
   if (is_trained(x)) {
-    cols <- tibble(terms = names(x$objects))
+    terms <- names(x$objects)
   } else {
-    cols <- sel2char(x$terms)
+    terms <- sel2char(x$terms)
   }
-  res <- expand.grid(terms = cols, stringsAsFactors = FALSE)
-  res$id <- x$id
-  as_tibble(res)
+  tibble(terms = terms, id = x$id)
 }
 
-
-
-#' @rdname tunable.step
 #' @export
 tunable.step_ns <- function(x, ...) {
   tibble::tibble(
