@@ -5,26 +5,16 @@
 #'  and unbalanced.
 #'
 #' @inheritParams step_center
-#' @param ... One or more selector functions to choose which
-#'  variables that will be evaluated by the filtering. See
-#'  [selections()] for more details. For the `tidy`
-#'  method, these are not currently used.
-#' @param role Not used by this step since no new variables are
-#'  created.
 #' @param freq_cut,unique_cut Numeric parameters for the filtering process. See
 #'  the Details section below.
 #' @param options A list of options for the filter (see Details
 #'  below).
 #' @param removals A character string that contains the names of
 #'  columns that should be removed. These values are not determined
-#'  until [prep.recipe()] is called.
-#' @return An updated version of `recipe` with the new step
-#'  added to the sequence of existing steps (if any). For the
-#'  `tidy` method, a tibble with columns `terms` which
-#'  is the columns that will be removed.
-#' @keywords datagen
-#' @concept preprocessing
-#' @concept variable_filters
+#'  until [prep()] is called.
+#' @template step-return
+#' @template filter-steps
+#' @family variable filter steps
 #' @export
 #'
 #' @details This step diagnoses predictors that have one unique
@@ -47,11 +37,15 @@
 #'  unique values," the number of unique values divided by the total
 #'  number of samples (times 100), must also be below
 #'  `unique_cut`.
-
 #'
 #' In the above example, the frequency ratio is 999 and the unique
 #'  value percent is 0.2%.
-
+#'
+#' # Tidying
+#'
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble with column
+#' `terms` (the columns that will be removed) is returned.
+#'
 #' @examples
 #' library(modeldata)
 #' data(biomass)
@@ -75,9 +69,6 @@
 #'
 #' tidy(nzv_filter, number = 1)
 #' tidy(filter_obj, number = 1)
-#' @seealso [step_corr()] [recipe()]
-#'   [prep.recipe()] [bake.recipe()]
-
 step_nzv <-
   function(recipe,
            ...,
@@ -94,19 +85,17 @@ step_nzv <-
     if (!isTRUE(all.equal(exp_list, options))) {
       freq_cut <- options$freq_cut
       unique_cut <- options$unique_cut
-      message(
-        paste(
-          "The argument `options` is deprecated in favor of `freq_cut`",
-          "and `unique_cut`. options` will be removed in next version."
-        )
+      lifecycle::deprecate_stop(
+        "0.1.7",
+        "step_nzv(options)",
+        details = "Please use the arguments `freq_cut` and `unique_cut` instead."
       )
     }
 
-
     add_step(
       recipe,
       step_nzv_new(
-        terms = ellipse_check(...),
+        terms = enquos(...),
         role = role,
         trained = trained,
         freq_cut = freq_cut,
@@ -137,7 +126,8 @@ step_nzv_new <-
 
 #' @export
 prep.step_nzv <- function(x, training, info = NULL, ...) {
-  col_names <- terms_select(x$terms, info = info)
+  col_names <- recipes_eval_select(x$terms, training, info)
+
   filter <- nzv(
     x = training[, col_names],
     freq_cut = x$freq_cut,
@@ -167,19 +157,11 @@ bake.step_nzv <- function(object, new_data, ...) {
 print.step_nzv <-
   function(x, width = max(20, options()$width - 38), ...) {
     if (x$trained) {
-      if (length(x$removals) > 0) {
-        cat("Sparse, unbalanced variable filter removed ")
-        cat(format_ch_vec(x$removals, width = width))
-      } else
-        cat("Sparse, unbalanced variable filter removed no terms")
+      title <- "Sparse, unbalanced variable filter removed "
     } else {
-      cat("Sparse, unbalanced variable filter on ", sep = "")
-      cat(format_selectors(x$terms, width = width))
+      title <- "Sparse, unbalanced variable filter on "
     }
-    if (x$trained)
-      cat(" [trained]\n")
-    else
-      cat("\n")
+    print_step(x$removals, x$terms, x$trained, title, width)
     invisible(x)
   }
 
@@ -216,13 +198,10 @@ nzv <- function(x,
   colnames(x)[out]
 }
 
-#' @rdname step_nzv
-#' @param x A `step_nzv` object.
+#' @rdname tidy.recipe
 #' @export
 tidy.step_nzv <- tidy_filter
 
-
-#' @rdname tunable.step
 #' @export
 tunable.step_nzv <- function(x, ...) {
   tibble::tibble(
