@@ -4,17 +4,14 @@
 #'  numeric data into one or more principal components.
 #'
 #' @inheritParams step_center
-#' @inherit step_center return
-#' @param ... One or more selector functions to choose which variables will be
-#'  used to compute the components. See [selections()] for more details. For the
-#'  `tidy` method, these are not currently used.
 #' @param role For model terms created by this step, what analysis role should
-#'  they be assigned?. By default, the function assumes that the new principal
-#'  component columns created by the original variables will be used as
-#'  predictors in a model.
-#' @param num_comp The number of PCA components to retain as new predictors.
+#'  they be assigned? By default, the new columns created by this step from
+#'  the original variables will be used as _predictors_ in a model.
+#' @param num_comp The number of components to retain as new predictors.
 #'  If `num_comp` is greater than the number of columns or the number of
-#'  possible components, a smaller value will be used.
+#'  possible components, a smaller value will be used. If `num_comp = 0`
+#'  is set then no transformation is done and selected variables will
+#'  stay unchanged.
 #' @param threshold A fraction of the total variance that should be covered by
 #'  the components. For example, `threshold = .75` means that `step_pca` should
 #'  generate enough components to capture 75 percent of the variability in the
@@ -25,22 +22,15 @@
 #'  FALSE`, `scale. = FALSE`, and `tol = NULL`. **Note** that the argument `x`
 #'  should not be passed here (or at all).
 #' @param res The [stats::prcomp.default()] object is stored here once this
-#'  preprocessing step has be trained by [prep.recipe()].
-#' @param prefix A character string that will be the prefix to the resulting
-#'  new variables. See notes below.
-#' @param type For the `tidy()` method, either "coef" (for the variable
-#'  loadings per component) or "variance" (how much variance does each component
-#'  account for).
+#'  preprocessing step has be trained by [prep()].
+#' @param columns A character string of variable names that will
+#'  be populated elsewhere.
+#' @param prefix A character string for the prefix of the resulting new
+#'  variables. See notes below.
 #' @param keep_original_cols A logical to keep the original variables in the
 #'  output. Defaults to `FALSE`.
-#' @return An updated version of `recipe` with the new step added to the
-#'  sequence of existing steps (if any). For the `tidy` method, a tibble with
-#'  columns `terms` (the selectors or variables selected), `value` (the
-#'  loading), and `component`.
-#' @keywords datagen
-#' @concept preprocessing
-#' @concept pca
-#' @concept projection_methods
+#' @template step-return
+#' @family multivariate transformation steps
 #' @export
 #' @details
 #' Principal component analysis (PCA) is a transformation of a
@@ -70,6 +60,12 @@
 #'  number of components that are required to capture a specified
 #'  fraction of the total variance in the variables.
 #'
+#' # Tidying
+#'
+#' When you [`tidy()`][tidy.recipe()] this step, use either `type = "coef"`
+#' for the variable loadings per component or `type = "variance"` for how
+#' much variance each component accounts for.
+#'
 #' @references Jolliffe, I. T. (2010). *Principal Component
 #'  Analysis*. Springer.
 #'
@@ -93,9 +89,6 @@
 #'
 #' tidy(pca_trans, number = 2)
 #' tidy(pca_estimates, number = 2)
-#' @seealso [step_ica()] [step_kpca()]
-#'   [step_isomap()] [recipe()] [prep.recipe()]
-#'   [bake.recipe()]
 step_pca <- function(recipe,
                      ...,
                      role = "predictor",
@@ -104,6 +97,7 @@ step_pca <- function(recipe,
                      threshold = NA,
                      options = list(),
                      res = NULL,
+                     columns = NULL,
                      prefix = "PC",
                      keep_original_cols = FALSE,
                      skip = FALSE,
@@ -118,13 +112,14 @@ step_pca <- function(recipe,
   add_step(
     recipe,
     step_pca_new(
-      terms = ellipse_check(...),
+      terms = enquos(...),
       role = role,
       trained = trained,
       num_comp = num_comp,
       threshold = threshold,
       options = options,
       res = res,
+      columns = columns,
       prefix = prefix,
       keep_original_cols = keep_original_cols,
       skip = skip,
@@ -134,7 +129,7 @@ step_pca <- function(recipe,
 }
 
 step_pca_new <-
-  function(terms, role, trained, num_comp, threshold, options, res,
+  function(terms, role, trained, num_comp, threshold, options, res, columns,
            prefix,  keep_original_cols, skip, id) {
     step(
       subclass = "pca",
@@ -145,6 +140,7 @@ step_pca_new <-
       threshold = threshold,
       options = options,
       res = res,
+      columns = columns,
       prefix = prefix,
       keep_original_cols = keep_original_cols,
       skip = skip,
@@ -154,11 +150,11 @@ step_pca_new <-
 
 #' @export
 prep.step_pca <- function(x, training, info = NULL, ...) {
-  col_names <- eval_select_recipes(x$terms, training, info)
+  col_names <- recipes_eval_select(x$terms, training, info)
 
   check_type(training[, col_names])
 
-  if (x$num_comp > 0) {
+  if (x$num_comp > 0 && length(col_names) > 0) {
     prc_call <-
       expr(prcomp(
         retx = FALSE,
@@ -185,10 +181,7 @@ prep.step_pca <- function(x, training, info = NULL, ...) {
     ## e.g. `sdev` etc.
 
   } else {
-    # fake a rotation matrix so that the resolved names can be used for tidy()
-    fake_matrix <- matrix(NA, nrow = length(col_names))
-    rownames(fake_matrix) <- col_names
-    prc_obj <- list(rotation = fake_matrix)
+    prc_obj <- NULL
   }
 
   step_pca_new(
@@ -199,6 +192,7 @@ prep.step_pca <- function(x, training, info = NULL, ...) {
     threshold = x$threshold,
     options = x$options,
     res = prc_obj,
+    columns = col_names,
     prefix = x$prefix,
     keep_original_cols = get_keep_original_cols(x),
     skip = x$skip,
@@ -208,7 +202,7 @@ prep.step_pca <- function(x, training, info = NULL, ...) {
 
 #' @export
 bake.step_pca <- function(object, new_data, ...) {
-  if (!all(is.na(object$res$rotation))) {
+  if (length(object$columns) > 0 && !all(is.na(object$res$rotation))) {
     pca_vars <- rownames(object$res$rotation)
     comps <- predict(object$res, newdata = new_data[, pca_vars])
     comps <- comps[, 1:object$num_comp, drop = FALSE]
@@ -225,37 +219,39 @@ bake.step_pca <- function(object, new_data, ...) {
 
 print.step_pca <-
   function(x, width = max(20, options()$width - 29), ...) {
-    if (all(is.na(x$res$rotation))) {
-      cat("No PCA components were extracted.\n")
+    if (x$trained) {
+      if (length(x$columns) == 0 || all(is.na(x$res$rotation))) {
+        title <- "No PCA components were extracted from "
+        columns <- names(x$columns)
+      } else {
+        title <- glue::glue("PCA extraction with ")
+        columns <- rownames(x$res$rotation)
+      }
     } else {
-      cat("PCA extraction with ")
-      printer(rownames(x$res$rotation), x$terms, x$trained, width = width)
+      title <- "PCA extraction with "
     }
-
+    print_step(columns, x$terms, x$trained, title, width)
     invisible(x)
   }
 
 pca_coefs <- function(x) {
-  rot <- as.data.frame(x$res$rotation)
-  vars <- rownames(rot)
-  if (x$num_comp > 0) {
+  if (x$num_comp > 0 && length(x$columns) > 0) {
+    rot <- as.data.frame(x$res$rotation)
     npc <- ncol(rot)
     res <- utils::stack(rot)
     colnames(res) <- c("value", "component")
     res$component <- as.character(res$component)
-    res$terms <- rep(vars, npc)
+    res$terms <- rep(unname(x$columns), npc)
     res <- as_tibble(res)[, c("terms", "value", "component")]
   } else {
-    res <- tibble::tibble(terms = vars, value = rlang::na_dbl,
+    res <- tibble::tibble(terms = unname(x$columns), value = rlang::na_dbl,
                           component = rlang::na_chr)
   }
   res
 }
 
 pca_variances <- function(x) {
-  rot <- as.data.frame(x$res$rotation)
-  vars <- rownames(rot)
-  if (x$num_comp > 0) {
+  if (x$num_comp > 0 && length(x$columns) > 0) {
     variances <- x$res$sdev ^ 2
     p <- length(variances)
     tot <- sum(variances)
@@ -279,9 +275,9 @@ pca_variances <- function(x) {
                           component = rep(1:p, 4))
   } else {
     res <- tibble::tibble(
-      terms = vars,
-      value = rep(rlang::na_dbl, length(vars)),
-      component = rep(rlang::na_chr, length(vars))
+      terms = unname(x$columns),
+      value = rep(rlang::na_dbl, length(x$columns)),
+      component = rep(rlang::na_chr, length(x$columns))
     )
   }
   res
@@ -289,8 +285,10 @@ pca_variances <- function(x) {
 
 
 
-#' @rdname step_pca
-#' @param x A `step_pca` object.
+#' @rdname tidy.recipe
+#' @param type For `step_pca`, either `"coef"` (for the variable loadings per
+#' component) or `"variance"` (how much variance does each component
+#' account for).
 #' @export
 tidy.step_pca <- function(x, type = "coef", ...) {
   if (!is_trained(x)) {
@@ -310,9 +308,6 @@ tidy.step_pca <- function(x, type = "coef", ...) {
   res
 }
 
-
-
-#' @rdname tunable.step
 #' @export
 tunable.step_pca <- function(x, ...) {
   tibble::tibble(
