@@ -3,18 +3,8 @@
 #' `step_pls` creates a *specification* of a recipe step that will
 #'  convert numeric data into one or more new dimensions.
 #'
+#' @inheritParams step_pca
 #' @inheritParams step_center
-#' @inherit step_center return
-#' @param ... One or more selector functions to choose which variables will be
-#'  used to compute the dimensions. See [selections()] for more details. For the
-#'  `tidy` method, these are not currently used.
-#' @param role For model terms created by this step, what analysis role should
-#'  they be assigned?. By default, the function assumes that the new dimension
-#'  columns created by the original variables will be used as predictors in a
-#'  model.
-#' @param num_comp The number of pls dimensions to retain as new predictors.
-#'  If `num_comp` is greater than the number of columns or the number of
-#'  possible dimensions, a smaller value will be used.
 #' @param predictor_prop The maximum number of original predictors that can have
 #'  non-zero coefficients for each PLS component (via regularization).
 #' @param preserve Use `keep_original_cols` instead to specify whether the
@@ -26,19 +16,11 @@
 #' `mixOmics::plsda()`, or `mixOmics::splsda()` (depending on the data and
 #' arguments).
 #' @param res A list of results are stored here once this preprocessing step
-#'  has been trained by [prep.recipe()].
-#' @param prefix A character string that will be the prefix to the
-#'  resulting new variables. See notes below.
-#' @param keep_original_cols A logical to keep the original variables in the
-#'  output. Defaults to `FALSE`.
-#' @return An updated version of `recipe` with the new step
-#'  added to the sequence of existing steps (if any). For the
-#'  `tidy` method, a tibble with columns `terms` (the
-#'  selectors or variables selected), `components`, and `values`.
-#' @keywords datagen
-#' @concept preprocessing
-#' @concept pls
-#' @concept projection_methods
+#'  has been trained by [prep()].
+#' @param columns A character string of variable names that will
+#'  be populated elsewhere.
+#' @template step-return
+#' @family multivariate transformation steps
 #' @export
 #' @details PLS is a supervised version of principal component
 #'  analysis that requires the outcome data to compute
@@ -61,7 +43,10 @@
 #' proportion to determine the `keepX` parameter in `mixOmics::spls()` and
 #' `mixOmics::splsda()`. See the references in `mixOmics::spls()` for details.
 #'
-#' The `tidy()` method returns the coefficients that are usually defined as
+#' # Tidying
+#'
+#' The [`tidy()`][tidy.recipe()] method returns the coefficients that are
+#' usually defined as
 #'
 #' \deqn{W(P'W)^{-1}}
 #'
@@ -69,7 +54,8 @@
 #'
 #' When applied to data, these values are usually scaled by a column-specific
 #' norm. The `tidy()` method applies this same norm to the coefficients shown
-#' above.
+#' above. When you `tidy()` this step, a tibble with columns `terms` (the
+#' selectors or variables selected), `components`, and `values` is returned.
 #'
 #' @references
 #' \url{https://en.wikipedia.org/wiki/Partial_least_squares_regression}
@@ -120,9 +106,6 @@
 #'   recipe(class ~ ., data = cell_tr) %>%
 #'   step_pls(all_numeric_predictors(), outcome = "class", num_comp = 5, predictor_prop = 1/4)
 #'
-#' @seealso [step_pca()], [step_kpca()], [step_ica()], [recipe()],
-#'  [prep.recipe()], [bake.recipe()]
-
 step_pls <-
   function(recipe,
            ...,
@@ -134,6 +117,7 @@ step_pls <-
            options = list(scale = TRUE),
            preserve = deprecated(),
            res = NULL,
+           columns = NULL,
            prefix = "PLS",
            keep_original_cols = FALSE,
            skip = FALSE,
@@ -143,7 +127,7 @@ step_pls <-
     }
 
     if (lifecycle::is_present(preserve)) {
-      lifecycle::deprecate_soft(
+      lifecycle::deprecate_warn(
         "0.1.16",
         "step_pls(preserve = )",
         "step_pls(keep_original_cols = )"
@@ -156,7 +140,7 @@ step_pls <-
     add_step(
       recipe,
       step_pls_new(
-        terms = ellipse_check(...),
+        terms = enquos(...),
         role = role,
         trained = trained,
         num_comp = num_comp,
@@ -165,6 +149,7 @@ step_pls <-
         options = options,
         preserve = keep_original_cols,
         res = res,
+        columns = columns,
         prefix = prefix,
         keep_original_cols = keep_original_cols,
         skip = skip,
@@ -175,7 +160,7 @@ step_pls <-
 
 step_pls_new <-
   function(terms, role, trained, num_comp, predictor_prop, outcome, options,
-           preserve, res, prefix, keep_original_cols, skip, id) {
+           preserve, res, columns, prefix, keep_original_cols, skip, id) {
     step(
       subclass = "pls",
       terms = terms,
@@ -187,6 +172,7 @@ step_pls_new <-
       options = options,
       preserve = preserve,
       res = res,
+      columns = columns,
       prefix = prefix,
       keep_original_cols = keep_original_cols,
       skip = skip,
@@ -304,20 +290,27 @@ prop2int <- function(x, p) {
   as.integer(cut(x * p, breaks = cuts, include.lowest = TRUE))
 }
 
+get_columns_pls <- function(x) {
+  if (use_old_pls(x$res)) {
+    rownames(x$res$projection)
+  } else {
+    x$columns
+  }
+}
 
 ## -----------------------------------------------------------------------------
 
 #' @export
 prep.step_pls <- function(x, training, info = NULL, ...) {
-  x_names <- eval_select_recipes(x$terms, training, info)
-  y_names <- eval_select_recipes(x$outcome, training, info)
+  x_names <- recipes_eval_select(x$terms, training, info)
+  y_names <- recipes_eval_select(x$outcome, training, info)
 
   check_type(training[, x_names])
   if (length(y_names) > 1 ) {
     rlang::abort("`step_pls()` only supports univariate models.")
   }
 
-  if (x$num_comp > 0) {
+  if (x$num_comp > 0 && length(x_names) > 0) {
     ncomp <- min(x$num_comp,  length(x_names))
     # Convert proportion to number of terms
     x$predictor_prop <- max(x$predictor_prop, 0.00001)
@@ -334,7 +327,7 @@ prep.step_pls <- function(x, training, info = NULL, ...) {
     }
 
   } else {
-    res <- list(x_vars = x_names, y_vars = y_names)
+    res <- NULL
   }
 
   step_pls_new(
@@ -347,6 +340,7 @@ prep.step_pls <- function(x, training, info = NULL, ...) {
     options = x$options,
     preserve = x$preserve,
     res = res,
+    columns = x_names,
     prefix = x$prefix,
     keep_original_cols = get_keep_original_cols(x),
     skip = x$skip,
@@ -356,7 +350,7 @@ prep.step_pls <- function(x, training, info = NULL, ...) {
 
 #' @export
 bake.step_pls <- function(object, new_data, ...) {
-  if (object$num_comp > 0 & pls_worked(object$res)) {
+  if (object$num_comp > 0 && length(get_columns_pls(object)) > 0 && pls_worked(object$res)) {
 
     if (use_old_pls(object$res)) {
       comps <- old_pls_project(object$res, new_data)
@@ -391,22 +385,17 @@ bake.step_pls <- function(object, new_data, ...) {
 
 
 print.step_pls <- function(x, width = max(20, options()$width - 35), ...) {
-  if (x$num_comp == 0) {
-    cat("No PLS components were extracted.\n")
-  } else {
-    cat("PLS feature extraction with ")
-    printer(rownames(x$res$coefs), x$terms, x$trained, width = width)
-  }
+  title <- "PLS feature extraction with "
+  print_step(x$columns, x$terms, x$trained, title, width)
   invisible(x)
 }
 
 
-#' @rdname step_pls
-#' @param x A `step_pls` object
+#' @rdname tidy.recipe
 #' @export
 tidy.step_pls <- function(x, ...) {
   if (is_trained(x)) {
-    if (x$num_comp > 0) {
+    if (x$num_comp > 0 && length(get_columns_pls(x)) > 0) {
       res <-
         purrr::map2_dfc(as.data.frame(x$res$coefs), x$res$col_norms, ~ .x * .y) %>%
         dplyr::mutate(terms = rownames(x$res$coefs)) %>%
@@ -414,7 +403,7 @@ tidy.step_pls <- function(x, ...) {
       res <- res[, c("terms", "value", "component")]
       res$component <- gsub("comp", "PLS", res$component)
     } else {
-      res <- tibble(terms = rownames(x$res$coefs), value = na_dbl, component  = na_chr)
+      res <- tibble(terms = unname(get_columns_pls(x)), value = na_dbl, component  = na_chr)
     }
   } else {
     term_names <- sel2char(x$terms)
@@ -424,8 +413,6 @@ tidy.step_pls <- function(x, ...) {
   res
 }
 
-
-#' @rdname tunable.step
 #' @export
 tunable.step_pls <- function(x, ...) {
   tibble::tibble(
@@ -441,7 +428,7 @@ tunable.step_pls <- function(x, ...) {
 }
 
 
-#' @rdname required_pkgs.step
+#' @rdname required_pkgs.recipe
 #' @export
 required_pkgs.step_pls <- function(x, ...) {
   c("mixOmics")
