@@ -3,17 +3,9 @@
 #' `step_poly` creates a *specification* of a recipe
 #'  step that will create new columns that are basis expansions of
 #'  variables using orthogonal polynomials.
-
 #'
+#' @inheritParams step_pca
 #' @inheritParams step_center
-#' @param ... One or more selector functions to choose which
-#'  variables are affected by the step. See [selections()]
-#'  for more details.  For the `tidy` method, these are not
-#'  currently used.
-#' @param role For model terms created by this step, what analysis
-#'  role should they be assigned?. By default, the function assumes
-#'  that the new columns created from the original variables will be
-#'  used as predictors in a model.
 #' @param objects A list of [stats::poly()] objects
 #'  created once the step has been trained.
 #' @param degree The polynomial degree (an integer).
@@ -21,21 +13,22 @@
 #'  which should not include `x`, `degree`, or `simple`. Note that
 #'  the option `raw = TRUE` will produce the regular polynomial
 #'  values (not orthogonalized).
-#' @return An updated version of `recipe` with the new step
-#'  added to the sequence of existing steps (if any). For the
-#'  `tidy` method, a tibble with columns `terms` (the
-#'  columns that will be affected) and `degree`.
-#' @keywords datagen
-#' @concept preprocessing
-#' @concept basis_expansion
+#' @template step-return
+#' @family individual transformation steps
 #' @export
-#' @details `step_poly` can new features from a single
+#' @details `step_poly` can create new features from a single
 #'  variable that enable fitting routines to model this variable in
 #'  a nonlinear manner. The extent of the possible nonlinearity is
 #'  determined by the `degree` argument of
 #'  [stats::poly()]. The original variables are removed
 #'  from the data and new columns are added. The naming convention
 #'  for the new variables is `varname_poly_1` and so on.
+#'
+#'  # Tidying
+#'
+#'  When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
+#'  `terms` (the columns that will be affected) and `degree` is returned.
+#'
 #' @examples
 #' library(modeldata)
 #' data(biomass)
@@ -54,10 +47,6 @@
 #' expanded
 #'
 #' tidy(quadratic, number = 1)
-#' @seealso [step_ns()] [recipe()]
-#'   [prep.recipe()] [bake.recipe()]
-
-
 step_poly <-
   function(recipe,
            ...,
@@ -86,7 +75,7 @@ step_poly <-
     add_step(
       recipe,
       step_poly_new(
-        terms = ellipse_check(...),
+        terms = enquos(...),
         trained = trained,
         role = role,
         objects = objects,
@@ -130,7 +119,8 @@ poly_wrapper <- function(x, args) {
 
 #' @export
 prep.step_poly <- function(x, training, info = NULL, ...) {
-  col_names <- terms_select(x$terms, info = info)
+  col_names <- recipes_eval_select(x$terms, training, info)
+
   check_type(training[, col_names])
 
   opts <- x$options
@@ -156,25 +146,37 @@ prep.step_poly <- function(x, training, info = NULL, ...) {
 bake.step_poly <- function(object, new_data, ...) {
   col_names <- names(object$objects)
   new_names <- purrr::map(object$objects, ~ paste(attr(.x, "var"), "poly", 1:ncol(.x), sep = "_"))
-  poly_values <-
-    purrr::map2(new_data[, col_names], object$objects, ~ predict(.y, .x)) %>%
-    purrr::map(as_tibble) %>%
-    purrr::map2_dfc(new_names, ~ setNames(.x, .y))
-  new_data <- dplyr::bind_cols(new_data, poly_values)
-  new_data <- dplyr::select(new_data, -col_names)
+
+  # Start with n-row, 0-col tibble for the empty selection case
+  new_tbl <- tibble::new_tibble(x = list(), nrow = nrow(new_data))
+
+  for (i in seq_along(col_names)) {
+    i_col_name <- col_names[[i]]
+    i_col <- new_data[[i_col_name]]
+    i_object <- object$objects[[i]]
+    i_new_names <- new_names[[i]]
+
+    new_cols <- predict(i_object, i_col)
+    colnames(new_cols) <- i_new_names
+    new_cols <- tibble::as_tibble(new_cols)
+
+    new_tbl[i_new_names] <- new_cols
+  }
+
+  new_data <- dplyr::bind_cols(new_data, new_tbl)
+  new_data <- dplyr::select(new_data, -dplyr::all_of(col_names))
   new_data
 }
 
 
 print.step_poly <-
   function(x, width = max(20, options()$width - 35), ...) {
-    cat("Orthogonal polynomials on ")
-    printer(names(x$objects), x$terms, x$trained, width = width)
+    title <- "Orthogonal polynomials on "
+    print_step(names(x$objects), x$terms, x$trained, title, width)
     invisible(x)
   }
 
-#' @rdname step_poly
-#' @param x A `step_poly` object.
+#' @rdname tidy.recipe
 #' @export
 tidy.step_poly <- function(x, ...) {
   if (is_trained(x)) {
@@ -187,8 +189,6 @@ tidy.step_poly <- function(x, ...) {
   res
 }
 
-
-#' @rdname tunable.step
 #' @export
 tunable.step_poly <- function(x, ...) {
   tibble::tibble(
