@@ -4,18 +4,14 @@
 #'  step that will create one or more ratios out of numeric
 #'  variables.
 #'
+#' @inheritParams step_date
+#' @inheritParams step_pca
 #' @inheritParams step_center
-#' @inherit step_center return
 #' @param ... One or more selector functions to choose which
 #'  variables will be used in the *numerator* of the ratio.
 #'  When used with `denom_vars`, the dots indicate which
 #'  variables are used in the *denominator*. See
-#'  [selections()] for more details. For the `tidy`
-#'  method, these are not currently used.
-#' @param role For terms created by this step, what analysis role
-#'  should they be assigned?. By default, the function assumes that
-#'  the newly created ratios created by the original variables will
-#'  be used as predictors in a model.
+#'  [selections()] for more details.
 #' @param denom A call to `denom_vars` to specify which
 #'  variables are used in the denominator that can include specific
 #'  variable names separated by commas or different selectors (see
@@ -25,16 +21,16 @@
 #' @param naming A function that defines the naming convention for
 #'  new ratio columns.
 #' @param columns The column names used in the ratios. This
-#'  argument is not populated until [prep.recipe()] is
+#'  argument is not populated until [prep()] is
 #'  executed.
-#' @param keep_original_cols A logical to keep the original variables in the
-#'  output. Defaults to `TRUE`.
-#' @return An updated version of `recipe` with the new step
-#'  added to the sequence of existing steps (if any). For the
-#'  `tidy` method, a tibble with columns `terms` (the
-#'  selectors or variables selected) and `denom`.
-#' @keywords datagen
-#' @concept preprocessing
+#' @template step-return
+#' @details
+#'
+#' # Tidying
+#'
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
+#' `terms` (the selectors or variables selected) and `denom` is returned.
+#' @family multivariate transformation steps
 #' @export
 #' @examples
 #' library(recipes)
@@ -82,7 +78,7 @@ step_ratio <-
     add_step(
       recipe,
       step_ratio_new(
-        terms = ellipse_check(...),
+        terms = enquos(...),
         role = role,
         trained = trained,
         denom = denom,
@@ -116,14 +112,13 @@ step_ratio_new <-
 #' @export
 prep.step_ratio <- function(x, training, info = NULL, ...) {
   col_names <- expand.grid(
-    top = eval_select_recipes(x$terms, training, info),
-    bottom = eval_select_recipes(x$denom, training, info),
+    top = recipes_eval_select(x$terms, training, info),
+    bottom = recipes_eval_select(x$denom, training, info),
     stringsAsFactors = FALSE
   )
+  col_names <- tibble::as_tibble(col_names)
   col_names <- col_names[!(col_names$top == col_names$bottom), ]
 
-  if (nrow(col_names) == 0)
-    rlang::abort("No variables were selected for making ratios")
   if (any(info$type[info$variable %in% col_names$top] != "numeric"))
     rlang::abort("The ratio variables should be numeric")
   if (any(info$type[info$variable %in% col_names$bottom] != "numeric"))
@@ -144,13 +139,19 @@ prep.step_ratio <- function(x, training, info = NULL, ...) {
 
 #' @export
 bake.step_ratio <- function(object, new_data, ...) {
-  res <- new_data[, object$columns$top] /
-    new_data[, object$columns$bottom]
-  colnames(res) <-
-    apply(object$columns, 1, function(x)
-      object$naming(x[1], x[2]))
-  if (!is_tibble(res))
-    res <- as_tibble(res)
+  res <- purrr::map2(
+    new_data[, object$columns$top],
+    new_data[, object$columns$bottom],
+    `/`
+  )
+
+  names(res) <- apply(
+    object$columns,
+    MARGIN = 1,
+    function(x) object$naming(x[1], x[2])
+  )
+
+  res <- tibble::new_tibble(res, nrow = nrow(new_data))
 
   keep_original_cols <- get_keep_original_cols(object)
   new_data <- bind_cols(new_data, res)
@@ -167,16 +168,9 @@ bake.step_ratio <- function(object, new_data, ...) {
 
 print.step_ratio <-
   function(x, width = max(20, options()$width - 30), ...) {
-    cat("Ratios from ")
-    if (x$trained) {
-      vars <- c(unique(x$columns$top), unique(x$columns$bottom))
-      cat(format_ch_vec(vars, width = width))
-    } else
-      cat(format_selectors(c(x$terms, x$denom), width = width))
-    if (x$trained)
-      cat(" [trained]\n")
-    else
-      cat("\n")
+    title <- "Ratios from "
+    vars <- c(unique(x$columns$top), unique(x$columns$bottom))
+    print_step(vars, c(x$terms, x$denom), x$trained, title, width)
     invisible(x)
   }
 
@@ -184,8 +178,7 @@ print.step_ratio <-
 #' @rdname step_ratio
 denom_vars <- function(...) quos(...)
 
-#' @rdname step_ratio
-#' @param x A `step_ratio` object
+#' @rdname tidy.recipe
 #' @export
 tidy.step_ratio <- function(x, ...) {
   if (is_trained(x)) {
