@@ -3,21 +3,20 @@
 #' `step_rename_at` creates a *specification* of a recipe step that will rename
 #' the selected variables using a common function via [dplyr::rename_at()].
 #'
+#' @inheritParams step_pca
 #' @inheritParams step_center
 #' @param fn A function `fun`, a quosure style lambda `~ fun(.)`` or a list of
 #' either form (but containing only a single function, see [dplyr::rename_at()]).
 #' **Note that this argument must be named**.
-#' @param role For model terms created by this step, what analysis role should
-#'  they be assigned? By default, the function assumes that the new dimension
-#'  columns created by the original variables will be used as predictors in a
-#'  model.
-#' @param inputs A vector of column names populated by `prep()`.
-#' @return An updated version of `recipe` with the new step added to the
-#'  sequence of existing steps (if any). For the `tidy` method, a tibble with
-#'  columns `terms` which contains the columns being transformed.
-#' @keywords datagen
-#' @concept preprocessing
-#' @concept transformation_methods
+#' @param inputs A vector of column names populated by [prep()].
+#' @template step-return
+#' @details
+#'
+#' # Tidying
+#'
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
+#' `terms` which contains the columns being transformed is returned.
+#' @family dplyr steps
 #' @export
 #' @examples
 #' library(dplyr)
@@ -40,7 +39,7 @@ step_rename_at <- function(
   add_step(
     recipe,
     step_rename_at_new(
-      terms = ellipse_check(...),
+      terms = enquos(...),
       fn = fn,
       trained = trained,
       role = role,
@@ -67,7 +66,7 @@ step_rename_at_new <-
 
 #' @export
 prep.step_rename_at <- function(x, training, info = NULL, ...) {
-  col_names <- eval_select_recipes(x$terms, training, info)
+  col_names <- recipes_eval_select(x$terms, training, info)
 
   step_rename_at_new(
     terms = x$terms,
@@ -87,16 +86,16 @@ bake.step_rename_at <- function(object, new_data, ...) {
 
 print.step_rename_at <-
   function(x, width = max(20, options()$width - 35), ...) {
-    cat("Variable renaming for ", sep = "")
-    printer(x$inputs, x$terms, x$trained, width = width)
+    title <- "Variable renaming for "
+    print_step(x$inputs, x$terms, x$trained, title, width)
     invisible(x)
   }
 
-#' @rdname step_rename
+#' @rdname tidy.recipe
 #' @export
 tidy.step_rename_at <- function(x, ...) {
   if (is_trained(x)) {
-    res <- tibble(terms = x$inputs)
+    res <- tibble(terms = unname(x$inputs))
   } else {
     term_names <- sel2char(x$terms)
     res <- tibble(terms = term_names)
