@@ -4,22 +4,18 @@
 #'  that will remove variables based on their name, type, or role.
 #'
 #' @inheritParams step_center
-#' @param ... One or more selector functions to choose which
-#'  variables that will be evaluated by the filtering bake. See
-#'  [selections()] for more details. For the `tidy`
-#'  method, these are not currently used.
-#' @param role Not used by this step since no new variables are
-#'  created.
 #' @param removals A character string that contains the names of
 #'  columns that should be removed. These values are not determined
-#'  until [prep.recipe()] is called.
-#' @return An updated version of `recipe` with the new step
-#'  added to the sequence of existing steps (if any). For the
-#'  `tidy` method, a tibble with columns `terms` which
-#'  is the columns that will be removed.
-#' @keywords datagen
-#' @concept preprocessing
-#' @concept variable_filters
+#'  until [prep()] is called.
+#' @template step-return
+#' @template filter-steps
+#' @details
+#'
+#' # Tidying
+#'
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble with column
+#' `terms` (the columns that will be removed) is returned.
+#' @family variable filter steps
 #' @export
 #' @examples
 #' library(modeldata)
@@ -52,7 +48,7 @@ step_rm <- function(recipe,
   add_step(
     recipe,
     step_rm_new(
-      terms = ellipse_check(...),
+      terms = enquos(...),
       role = role,
       trained = trained,
       removals = removals,
@@ -76,7 +72,7 @@ step_rm_new <- function(terms, role, trained, removals, skip, id) {
 
 #' @export
 prep.step_rm <- function(x, training, info = NULL, ...) {
-  col_names <- eval_select_recipes(x$terms, training, info)
+  col_names <- recipes_eval_select(x$terms, training, info)
 
   step_rm_new(
     terms = x$terms,
@@ -98,27 +94,12 @@ bake.step_rm <- function(object, new_data, ...) {
 
 print.step_rm <-
   function(x, width = max(20, options()$width - 22), ...) {
-    if (x$trained) {
-      if (length(x$removals) > 0) {
-        cat("Variables removed ")
-        cat(format_ch_vec(x$removals, width = width))
-      } else {
-        cat("No variables were removed")
-      }
-    } else {
-      cat("Delete terms ", sep = "")
-      cat(format_selectors(x$terms, width = width))
-    }
-    if (x$trained) {
-      cat(" [trained]\n")
-    } else {
-      cat("\n")
-    }
+    title <- "Variables removed "
+    print_step(x$removals, x$terms, x$trained, title, width)
     invisible(x)
   }
 
 
-#' @rdname step_rm
-#' @param x A `step_rm` object.
+#' @rdname tidy.recipe
 #' @export
 tidy.step_rm <- tidy_filter
