@@ -4,31 +4,25 @@
 #'  that will sample rows using [dplyr::sample_n()] or
 #'  [dplyr::sample_frac()].
 #'
+#' @template row-ops
 #' @inheritParams step_center
 #' @param ... Argument ignored; included for consistency with other step
-#'  specification functions. For the `tidy`
-#'  method, these are not currently used.
-#' @param role Not used by this step since no new variables are
-#'  created.
+#'  specification functions.
 #' @param size An integer or fraction. If the value is within (0, 1),
 #'  [dplyr::sample_frac()] is applied to the data. If an integer
 #'  value of 1 or greater is used, [dplyr::sample_n()] is applied.
 #'  The default of `NULL` uses [dplyr::sample_n()] with the size
 #'  of the training set (or smaller for smaller `new_data`).
-#' @param skip A logical. Should the step be skipped when the
-#'  recipe is baked by [bake.recipe()]? While all operations are baked
-#'  when [prep.recipe()] is run, some operations may not be able to be
-#'  conducted on new data (e.g. processing the outcome variable(s)).
-#'  Care should be taken when using `skip = FALSE`; in most instances that
-#'  affect the rows of the data being predicted, this step probably should not
-#'  be applied.
 #' @param replace Sample with or without replacement?
-#' @return An updated version of `recipe` with the new step
-#'  added to the sequence of existing steps (if any). For the
-#'  `tidy` method, a tibble with columns `size`, `replace`,
-#'  and `id`.
-#' @keywords datagen
-#' @concept preprocessing
+#' @template step-return
+#' @details
+#'
+#' # Tidying
+#'
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
+#' `size`, `replace`, and `id` is returned.
+#' @family row operation steps
+#' @family dplyr steps
 #' @export
 #' @examples
 #'
@@ -54,8 +48,6 @@
 #'
 #' bake(smaller_cars, new_data = NULL) %>% nrow()
 #' bake(smaller_cars, new_data = mtcars %>% slice(21:32)) %>% nrow()
-
-
 step_sample <- function(
   recipe, ...,
   role = NA,
@@ -142,20 +134,16 @@ bake.step_sample <- function(object, new_data, ...) {
 
 print.step_sample <-
   function(x, width = max(20, options()$width - 35), ...) {
-    cat("Row sampling")
-    if (x$replace)
-      cat(" with replacement")
-    if (x$trained) {
-      cat(" [trained]\n")
-    } else {
-      cat("\n")
+    title <- "Row sampling "
+    if (x$replace) {
+      title <- paste(title, "with replacement ")
     }
+    print_step(NULL, NULL, x$trained, title, width)
     invisible(x)
   }
 
 
-#' @rdname step_sample
-#' @param x A `step_sample` object
+#' @rdname tidy.recipe
 #' @export
 tidy.step_sample <- function(x, ...) {
   tibble(
