@@ -5,24 +5,17 @@
 #'  variables.
 #'
 #' @inheritParams step_center
-#' @inherit step_center return
-#' @param ... One or more selector functions to choose which
-#'  variables will be permuted. See [selections()] for more
-#'  details. For the `tidy` method, these are not
-#'  currently used.
-#' @param role Not used by this step since no new variables are
-#'  created.
 #' @param columns A character string that contains the names of
 #'  columns that should be shuffled. These values are not determined
-#'  until [prep.recipe()] is called.
-#' @return An updated version of `recipe` with the new step
-#'  added to the sequence of existing steps (if any). For the
-#'  `tidy` method, a tibble with columns `terms` which
-#'  is the columns that will be affected.
-#' @keywords datagen
-#' @concept preprocessing
-#' @concept randomization
-#' @concept permutation
+#'  until [prep()] is called.
+#' @template step-return
+#' @details
+#'
+#' # Tidying
+#'
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble with column
+#' `terms` (the columns that will be permuted) is returned.
+#' @family row operation steps
 #' @export
 #' @examples
 #' integers <- data.frame(A = 1:12, B = 13:24, C = 25:36)
@@ -48,7 +41,7 @@ step_shuffle <- function(recipe,
                          id = rand_id("shuffle")) {
   add_step(recipe,
            step_shuffle_new(
-             terms = ellipse_check(...),
+             terms = enquos(...),
              role = role,
              trained = trained,
              columns = columns,
@@ -71,7 +64,7 @@ step_shuffle_new <- function(terms, role, trained, columns, skip, id) {
 
 #' @export
 prep.step_shuffle <- function(x, training, info = NULL, ...) {
-  col_names <- terms_select(x$terms, info = info)
+  col_names <- recipes_eval_select(x$terms, training, info)
   step_shuffle_new(
     terms = x$terms,
     role = x$role,
@@ -98,13 +91,12 @@ bake.step_shuffle <- function(object, new_data, ...) {
 
 print.step_shuffle <-
   function(x, width = max(20, options()$width - 22), ...) {
-    cat("Shuffled ")
-    printer(x$columns, x$terms, x$trained, width = width)
+    title <- "Shuffled "
+    print_step(x$columns, x$terms, x$trained, title, width)
     invisible(x)
   }
 
-#' @rdname step_shuffle
-#' @param x A `step_shuffle` object.
+#' @rdname tidy.recipe
 #' @export
 tidy.step_shuffle <- function(x, ...) {
   res <-simple_terms(x, ...)
