@@ -21,8 +21,10 @@
 #' The variables should be centered and scaled prior to the
 #'  computations.
 #'
-#' When you [`tidy()`] this step, a tibble with column `terms` (the columns
-#'  that will be affected) is returned.
+#' # Tidying
+#'
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble with column
+#' `terms` (the columns that will be affected) is returned.
 #'
 #' @references Serneels, S., De Nolf, E., and Van Espen, P.
 #'  (2006). Spatial sign preprocessing: a simple way to impart
@@ -66,7 +68,7 @@ step_spatialsign <-
            id = rand_id("spatialsign")) {
     add_step(recipe,
              step_spatialsign_new(
-               terms = ellipse_check(...),
+               terms = enquos(...),
                role = role,
                na_rm = na_rm,
                trained = trained,
@@ -121,8 +123,8 @@ bake.step_spatialsign <- function(object, new_data, ...) {
 
 print.step_spatialsign <-
   function(x, width = max(20, options()$width - 26), ...) {
-    cat("Spatial sign on  ", sep = "")
-    printer(x$columns, x$terms, x$trained, width = width)
+    title <- "Spatial sign on  "
+    print_step(x$columns, x$terms, x$trained, title, width)
     invisible(x)
   }
 
