@@ -21,8 +21,11 @@
 #'  data will be applied to `step_string2factor`. However, this step
 #'  can also take existing factors (but will leave them as-is).
 #'
-#'  When you [`tidy()`] this step, a tibble with columns `terms` (the
-#'  selectors or variables selected) and `ordered` is returned.
+#'  # Tidying
+#'
+#'  When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
+#'  `terms` (the selectors or variables selected) and `ordered` is
+#'  returned.
 #'
 #' @examples
 #' library(modeldata)
@@ -62,7 +65,7 @@ step_string2factor <-
     add_step(
       recipe,
       step_string2factor_new(
-        terms = ellipse_check(...),
+        terms = enquos(...),
         role = role,
         trained = trained,
         levels = levels,
@@ -138,16 +141,16 @@ bake.step_string2factor <- function(object, new_data, ...) {
 
   if (is.list(object$levels)) {
     new_data[, col_names] <-
-      map2_df(new_data[, col_names],
-              object$levels,
-              make_factor,
-              ord = object$ordered[1])
+      purrr::map2(new_data[, col_names],
+                  object$levels,
+                  make_factor,
+                  ord = object$ordered[1])
   } else {
     new_data[, col_names] <-
-      map_df(new_data[, col_names],
-             make_factor,
-             lvl = object$levels,
-             ord = object$ordered[1])
+      map(new_data[, col_names],
+          make_factor,
+          lvl = object$levels,
+          ord = object$ordered[1])
   }
 
   if (!is_tibble(new_data))
@@ -157,8 +160,8 @@ bake.step_string2factor <- function(object, new_data, ...) {
 
 print.step_string2factor <-
   function(x, width = max(20, options()$width - 30), ...) {
-    cat("Factor variables from ")
-    printer(names(x$ordered), x$terms, x$trained, width = width)
+    title <- "Factor variables from "
+    print_step(names(x$ordered), x$terms, x$trained, title, width)
     invisible(x)
   }
 
@@ -170,10 +173,10 @@ tidy.step_string2factor <- function(x, ...) {
   p <- length(term_names)
   if (is_trained(x)) {
     res <- tibble(terms = term_names,
-                  ordered = rep(x$ordered, p))
+                  ordered = rep(unname(x$ordered), p))
   } else {
     res <- tibble(terms = term_names,
-                  ordered = rep(x$ordered, p))
+                  ordered = rep(unname(x$ordered), p))
   }
   res$id <- x$id
   res
