@@ -4,25 +4,13 @@
 #'  step that will assign a missing value in a factor level to"unknown".
 #'
 #' @inheritParams step_center
-#' @inherit step_center return
-#' @param ... One or more selector functions to choose which
-#'  variables that will be affected by the step. These variables
-#'  should be character or factor types. See [selections()] for more
-#'  details. For the `tidy` method, these are not currently used.
-#' @param role Not used by this step since no new variables are
-#'  created.
 #' @param new_level A single character value that will be assigned
 #'  to new factor levels.
 #' @param objects A list of objects that contain the information
-#'  on factor levels that will be determined by [prep.recipe()].
-#' @return An updated version of `recipe` with the new step
-#'  added to the sequence of existing steps (if any). For the
-#'  `tidy` method, a tibble with columns `terms` (the
-#'  columns that will be affected) and `value` (the factor
-#'  levels that is used for the new value)
-#' @keywords datagen
-#' @concept preprocessing
-#' @concept factors
+#'  on factor levels that will be determined by [prep()].
+#' @template step-return
+#' @family dummy variable and encoding steps
+#' @seealso [dummy_names()]
 #' @export
 #' @details The selected variables are adjusted to have a new
 #'  level (given by `new_level`) that is placed in the last
@@ -34,9 +22,12 @@
 #' If `new_level` is already in the data given to `prep`, an error
 #'  is thrown.
 #'
-#' @seealso [step_factor2string()], [step_string2factor()],
-#'  [dummy_names()], [step_regex()], [step_count()],
-#'  [step_ordinalscore()], [step_unorder()], [step_other()], [step_novel()]
+#' # Tidying
+#'
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
+#' `terms` (the columns that will be affected) and `value` (the factor
+#'  levels that is used for the new value) is returned.
+#'
 #' @examples
 #' library(modeldata)
 #' data(okc)
@@ -67,7 +58,7 @@ step_unknown <-
     add_step(
       recipe,
       step_unknown_new(
-        terms = ellipse_check(...),
+        terms = enquos(...),
         role = role,
         trained = trained,
         new_level = new_level,
@@ -94,7 +85,7 @@ step_unknown_new <-
 
 #' @export
 prep.step_unknown <- function(x, training, info = NULL, ...) {
-  col_names <- eval_select_recipes(x$terms, training, info)
+  col_names <- recipes_eval_select(x$terms, training, info)
   col_check <- dplyr::filter(info, variable %in% col_names)
   if (any(col_check$type != "nominal"))
     rlang::abort(
@@ -159,13 +150,12 @@ bake.step_unknown <- function(object, new_data, ...) {
 
 print.step_unknown <-
   function(x, width = max(20, options()$width - 30), ...) {
-    cat("Unknown factor level assignment for ", sep = "")
-    printer(names(x$objects), x$terms, x$trained, width = width)
+    title <- "Unknown factor level assignment for "
+    print_step(names(x$objects), x$terms, x$trained, title, width)
     invisible(x)
   }
 
-#' @rdname step_unknown
-#' @param x A `step_unknown` object.
+#' @rdname tidy.recipe
 #' @export
 tidy.step_unknown <- function(x, ...) {
   if (is_trained(x)) {
