@@ -4,23 +4,18 @@
 #'  step that will transform the data.
 #'
 #' @inheritParams step_center
-#' @param ... One or more selector functions to choose which
-#'  variables are affected by the step. See [selections()]
-#'  for more details. For the `tidy` method, these are not
-#'  currently used.
-#' @param role Not used by this step since no new variables are
-#'  created.
 #' @param columns A character string of variable names that will
 #'  be populated (eventually) by the `terms` argument.
-#' @return An updated version of `recipe` with the new step
-#'  added to the sequence of existing steps (if any). For the
-#'  `tidy` method, a tibble with columns `terms` (the
-#'  columns that will be affected).
-#' @keywords datagen
-#' @concept preprocessing
-#' @concept ordinal_data
+#' @template step-return
+#' @family dummy variable and encoding steps
 #' @export
 #' @details The factors level order is preserved during the transformation.
+#'
+#' # Tidying
+#'
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble with column
+#' `terms` (the columns that will be affected) is returned.
+#'
 #' @examples
 #' lmh <- c("Low", "Med", "High")
 #'
@@ -40,9 +35,6 @@
 #'
 #' tidy(factor_trans, number = 1)
 #' tidy(factor_obj, number = 1)
-#' @seealso [step_ordinalscore()] [recipe()]
-#' [prep.recipe()] [bake.recipe()]
-
 step_unorder <-
   function(recipe,
            ...,
@@ -53,7 +45,7 @@ step_unorder <-
            id = rand_id("unorder")) {
     add_step(recipe,
              step_unorder_new(
-               terms = ellipse_check(...),
+               terms = enquos(...),
                role = role,
                trained = trained,
                columns = columns,
@@ -77,25 +69,21 @@ step_unorder_new <-
 
 #' @export
 prep.step_unorder <- function(x, training, info = NULL, ...) {
-  col_names <- eval_select_recipes(x$terms, training, info)
+  col_names <- recipes_eval_select(x$terms, training, info)
   order_check <- vapply(training[, col_names],
                         is.ordered,
                         logical(1L))
-  if(all(!order_check)) {
-    rlang::abort("`step_unorder` required ordered factors.")
-  } else {
-    if(any(!order_check)) {
-      bad_cols <- names(order_check)[!order_check]
-      bad_cols <- paste0(bad_cols, collapse = ", ")
-      rlang::warn(
-        paste0(
-          "`step_unorder` requires ordered factors. Variables ",
-          bad_cols,
-          " will be ignored."
-        )
+  if(any(!order_check)) {
+    bad_cols <- names(order_check)[!order_check]
+    bad_cols <- paste0(bad_cols, collapse = ", ")
+    rlang::warn(
+      paste0(
+        "`step_unorder` requires ordered factors. Variables ",
+        bad_cols,
+        " will be ignored."
       )
-      col_names <- names(order_check)[order_check]
-    }
+    )
+    col_names <- names(order_check)[order_check]
   }
 
   step_unorder_new(
@@ -120,14 +108,13 @@ bake.step_unorder <- function(object, new_data, ...) {
 
 print.step_unorder <-
   function(x, width = max(20, options()$width - 33), ...) {
-    cat("Unordered variables ", sep = "")
-    printer(x$columns, x$terms, x$trained, width = width)
+    title <- "Unordered variables "
+    print_step(x$columns, x$terms, x$trained, title, width)
     invisible(x)
   }
 
 
-#' @rdname step_unorder
-#' @param x A `step_unorder` object.
+#' @rdname tidy.recipe
 #' @export
 tidy.step_unorder <- function(x, ...) {
   res <- simple_terms(x, ...)
