@@ -21,7 +21,7 @@
 #'  `'var'`
 #' @param columns A character string that contains the names of
 #'  columns that should be processed. These values are not
-#'  determined until [prep.recipe()] is called.
+#'  determined until [prep()] is called.
 #' @param names An optional character string that is the same
 #'  length of the number of terms selected by `terms`. If you
 #'  are not sure what columns will be selected, use the
@@ -42,9 +42,11 @@
 #  This step requires the \pkg{RcppRoll} package. If not installed, the
 #'  step will stop with a note about installing the package.
 #'
-#' When you [`tidy()`] this step, a tibble with columns `terms` (the
-#'  selectors or variables selected), `statistic` (the
-#'  summary function name), and `size` is returned.
+#' # Tidying
+#'
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
+#' `terms` (the selectors or variables selected), `statistic` (the
+#' summary function name), and `size` is returned.
 #'
 #' @examples
 #' library(recipes)
@@ -145,7 +147,7 @@ step_window <-
     add_step(
       recipe,
       step_window_new(
-        terms = ellipse_check(...),
+        terms = enquos(...),
         trained = trained,
         role = role,
         size = size,
@@ -260,15 +262,8 @@ bake.step_window <- function(object, new_data, ...) {
 
 print.step_window <-
   function(x, width = max(20, options()$width - 28), ...) {
-    cat("Moving ", x$size, "-point ", x$statistic, " on ", sep = "")
-    if (x$trained) {
-      cat(format_ch_vec(x$columns, width = width))
-    } else
-      cat(format_selectors(x$terms, width = width))
-    if (x$trained)
-      cat(" [trained]\n")
-    else
-      cat("\n")
+    title <- glue::glue("Moving {x$size}-point {x$statistic} on ")
+    print_step(x$columns, x$terms, x$trained, title, width)
     invisible(x)
   }
 
@@ -282,8 +277,6 @@ tidy.step_window <- function(x, ...) {
   out
 }
 
-
-#' @rdname tunable.recipe
 #' @export
 tunable.step_window <- function(x, ...) {
   tibble::tibble(
