@@ -3,6 +3,7 @@ library(glue)
 # set up the boilerplate for a new step or check
 # creates a prefilled script in /R
 # and an empty script in /tests
+# consider using @inheritParams where appropriate instead of full boilerplate
 make_new <- function(name,
                      which = c("step", "check")) {
   which <- match.arg(which)
@@ -54,19 +55,22 @@ create_documentation <- function(name,
 #'  preprocessing have been estimated.
 #' <additional args here>
 #' @param skip A logical. Should the step be skipped when the
-#'  recipe is baked by [bake.recipe()]? While all operations are baked
-#'  when [prep.recipe()] is run, some operations may not be able to be
+#'  recipe is baked by [bake()]? While all operations are baked
+#'  when [prep()] is run, some operations may not be able to be
 #'  conducted on new data (e.g. processing the outcome variable(s)).
 #'  Care should be taken when using `skip = TRUE` as it may affect
 #'  the computations for subsequent operations
 #' @param id A character string that is unique to this step to identify it.
 #' @return <describe return>
 #'
-#' @keywords datagen
-#' @concept preprocessing
 #' @export
 #' @details <describe details>
 #'
+#' # Tidying
+#'
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
+#' <describe tidying> is returned.
+#'
 #' @examples
 
   ")
@@ -85,7 +89,7 @@ create_function <- function(name, which) {
       add_{which}(
         recipe,
         {which}_{name}_new(
-          terms = ellipse_check(...),
+          terms = enquos(...),
           trained = trained,
           role = role,
           <additional args here>
@@ -119,7 +123,7 @@ create_generator <- function(name, which) {
 create_prep_method <- function(name, which) {
   glue('
 prep.{which}_{name} <- function(x, training, info = NULL, ...) {{
-  col_names <- eval_select_recipes(x$terms, training, info)
+  col_names <- recipes_eval_select(x$terms, training, info)
   check_type(training[, col_names])
 
   <prepping action here>
@@ -151,8 +155,8 @@ create_print_method <- function(name, which) {
   glue('
 print.{which}_{name} <-
   function(x, width = max(20, options()$width - 30), ...) {{
-    cat("<describe action here> ", sep = "")
-    printer(names(x$means), x$terms, x$trained, width = width)
+    title <- "<describe action here> "
+    print_step(names(x$means), x$terms, x$trained, title, width)
     invisible(x)
   }}
 
