@@ -1,6 +1,7 @@
 library(testthat)
 library(recipes)
 
+
 n <- 20
 
 set.seed(752)
@@ -24,10 +25,10 @@ score <- function(x) as.numeric(x)^2
 test_that('linear scores', {
   rec1 <- recipe(~ ., data = ex_dat) %>%
     step_ordinalscore(starts_with("ord"))
-  rec1 <- prep(rec1, training = ex_dat, retain = TRUE,
-                  stringsAsFactors = FALSE, verbose = FALSE)
-  rec1_scores <- bake(rec1, newdata = ex_dat)
-  rec1_scores_NA <- bake(rec1, newdata = ex_miss)
+  rec1 <- prep(rec1, training = ex_dat,
+               strings_as_factors = FALSE, verbose = FALSE)
+  rec1_scores <- bake(rec1, new_data = ex_dat)
+  rec1_scores_NA <- bake(rec1, new_data = ex_miss)
 
   expect_equal(as.numeric(ex_dat$ord1), rec1_scores$ord1)
   expect_equal(as.numeric(ex_dat$ord2), rec1_scores$ord2)
@@ -41,10 +42,10 @@ test_that('nonlinear scores', {
   rec2 <- recipe(~ ., data = ex_dat) %>%
     step_ordinalscore(starts_with("ord"),
                       convert = score)
-  rec2 <- prep(rec2, training = ex_dat, retain = TRUE,
-                  stringsAsFactors = FALSE, verbose = FALSE)
-  rec2_scores <- bake(rec2, newdata = ex_dat)
-  rec2_scores_NA <- bake(rec2, newdata = ex_miss)
+  rec2 <- prep(rec2, training = ex_dat,
+               strings_as_factors = FALSE, verbose = FALSE)
+  rec2_scores <- bake(rec2, new_data = ex_dat)
+  rec2_scores_NA <- bake(rec2, new_data = ex_miss)
 
   expect_equal(as.numeric(ex_dat$ord1)^2, rec2_scores$ord1)
   expect_equal(as.numeric(ex_dat$ord2)^2, rec2_scores$ord2)
@@ -58,8 +59,6 @@ test_that('bad spec', {
   rec3 <- recipe(~ ., data = ex_dat) %>%
     step_ordinalscore(everything())
   expect_error(prep(rec3, training = ex_dat, verbose = FALSE))
-  rec4 <- recipe(~ ., data = ex_dat)
-  expect_error(rec4 %>% step_ordinalscore())
 })
 
 
@@ -70,3 +69,40 @@ test_that('printing', {
   expect_output(prep(rec5, training = ex_dat, verbose = TRUE))
 })
 
+test_that("empty selection prep/bake is a no-op", {
+  rec1 <- recipe(mpg ~ ., mtcars)
+  rec2 <- step_ordinalscore(rec1)
+
+  rec1 <- prep(rec1, mtcars)
+  rec2 <- prep(rec2, mtcars)
+
+  baked1 <- bake(rec1, mtcars)
+  baked2 <- bake(rec2, mtcars)
+
+  expect_identical(baked1, baked2)
+})
+
+test_that("empty selection tidy method works", {
+  rec <- recipe(mpg ~ ., mtcars)
+  rec <- step_ordinalscore(rec)
+
+  expect <- tibble(terms = character(), id = character())
+
+  expect_identical(tidy(rec, number = 1), expect)
+
+  rec <- prep(rec, mtcars)
+
+  expect_identical(tidy(rec, number = 1), expect)
+})
+
+test_that("empty printing", {
+  skip_if(packageVersion("rlang") < "1.0.0")
+  rec <- recipe(mpg ~ ., mtcars)
+  rec <- step_ordinalscore(rec)
+
+  expect_snapshot(rec)
+
+  rec <- prep(rec, mtcars)
+
+  expect_snapshot(rec)
+})
