@@ -1,9 +1,8 @@
 library(testthat)
 library(recipes)
+library(modeldata)
 data(biomass)
 
-context("Polynomial features")
-
 
 biomass_tr <- biomass[biomass$dataset == "Training",]
 biomass_te <- biomass[biomass$dataset == "Testing",]
@@ -82,3 +81,60 @@ test_that('tunable', {
     c('name', 'call_info', 'source', 'component', 'component_id')
   )
 })
+
+
+
+test_that('old option argument', {
+  expect_message(
+    res <-
+      recipe(~ ., data = iris) %>%
+      step_poly(Sepal.Width, options = list(degree = 3)) %>%
+      prep() %>%
+      juice(),
+    "The `degree` argument is now a main argument"
+  )
+  exp_names <- c('Sepal.Length', 'Petal.Length', 'Petal.Width', 'Species',
+                 'Sepal.Width_poly_1', 'Sepal.Width_poly_2', 'Sepal.Width_poly_3')
+  expect_equal(
+    names(res),
+    exp_names
+  )
+})
+
+test_that("empty selection prep/bake is a no-op", {
+  rec1 <- recipe(mpg ~ ., mtcars)
+  rec2 <- step_poly(rec1)
+
+  rec1 <- prep(rec1, mtcars)
+  rec2 <- prep(rec2, mtcars)
+
+  baked1 <- bake(rec1, mtcars)
+  baked2 <- bake(rec2, mtcars)
+
+  expect_identical(baked1, baked2)
+})
+
+test_that("empty selection tidy method works", {
+  rec <- recipe(mpg ~ ., mtcars)
+  rec <- step_poly(rec)
+
+  expect <- tibble(terms = character(), degree = integer(), id = character())
+
+  expect_identical(tidy(rec, number = 1), expect)
+
+  rec <- prep(rec, mtcars)
+
+  expect_identical(tidy(rec, number = 1), expect)
+})
+
+test_that("empty printing", {
+  skip_if(packageVersion("rlang") < "1.0.0")
+  rec <- recipe(mpg ~ ., mtcars)
+  rec <- step_poly(rec)
+
+  expect_snapshot(rec)
+
+  rec <- prep(rec, mtcars)
+
+  expect_snapshot(rec)
+})
